import exp from "constants";

export enum ShippingMethodType {
  FreeShipping = 'Livraison gratuite',
  FlatRate = 'Forfait',
  ColissimoWithoutSignature = 'Colissimo sans signature',
  ColissimoWithSignature = 'Colissimo avec signature',
  MondialRelay = 'Mondial Relay - InPost',
  PointOfSale = 'Point de vente'
}


export type IShippingAreaItem = {
  id: string;
  name: string;
  order: number;
  regionList: string[];
  shippingMethodList: ShippingMethod[];
};

export type ShippingMethod =
  | { id: string; name: string; active: boolean; type: ShippingMethodType.FreeShipping; description: string; data: FreeShipping }
  | { id: string; name: string; active: boolean; type: ShippingMethodType.FlatRate; description: string; data: FlatRate }
  | { id: string; name: string; active: boolean; type: ShippingMethodType.MondialRelay; description: string; data: MondialRelay }
  | { id: string; name: string; active: boolean; type: ShippingMethodType.ColissimoWithSignature; description: string; data: null }
  | { id: string; name: string; active: boolean; type: ShippingMethodType.ColissimoWithoutSignature; description: string; data: null }
  | { id: string; name: string; active: boolean; type: ShippingMethodType.PointOfSale; description: string; data: null };

export type FreeShipping = {
  requires: RequiresFreeShipping | String;
  minimumOrderAmount: number;
  applyMinOrderRuleBeforePromoCodeDiscount: string;
};

export type FlatRate = {
  tvaStatut: boolean;
  cost: number;
  costHeavyShippingClass: number;
  CostNoShippingClass: number;
  calculationType: CalculationType;
};

export type MondialRelay = {
  amountFreeShipping: number;
  nameFreeShipping: string;
  modeMondialRelay: MondialRelayMode;
  listCostDelivery: { weightCart: number; weightPackaging: number; cost: number }[];
};

export type PointOfSale = {
  tvaStatut: boolean;
  cost: number;
};

export type MondialRelayCostDelivery = {
  id: string;
  weightCart: number;
  weightPackaging: number;
  cost: number
}

export type ShippingClass = {
  id: string;
  name: string;
  code: string;
  description: string;
  productAssigned: number;
};


//Select components value
export enum RequiresFreeShipping {
  Nothing = 'Aucun prérequis',
  PromoCode = 'Un code promo d’expédition gratuite valide',
  MinimumOrderAmount = 'Montant minimum de commande',
  PromoCodeOrMinimumOrderAmount = 'Montant minimum de commande ou un code promo',
  PromoCodeAndMinimumOrderAmount = 'Montant minimum de commande et un code promo'
}

export enum CalculationType {
  ByClass = 'Par classe : frais d’envoi pour chaque classe d’expédition',
  ByOrder = 'Par commande : frais d’envoi pour la classe d’expédition la plus coûteuse',
}

export enum MondialRelayMode {
  MED = '24R/MED - livraison en Point Relais®',
  APM = '24R/APM - livraison en Lockers',
  HOM = 'HOM - livraison domicile HOME',
  PRL = '(obsolète) 24R - livraison en Point Relais® et lockers',
  HOC = 'HOC - livraison HOC (indisponible avec l’offre Start)',
  HOD = 'HOD - livraison HOD (indisponible avec l’offre Start)',
  OMR = 'Livraison hors Mondial Relay - InPost'
}



// ----------------------------------------------------------------------

export type IOrderColissimoItem = {
  id: string;
  date: Date;
  idClient: string;
  adresse: string;
  pays: string;
  shippingMethod: ShippingMethodType;
  status: string;
};

export type IOrderColissimoTableFilterValue = string | string[] | Date | null;

export type IOrderColissimoTableFilters = {
  country: string[];
  method: string[];
  status: string[];
  etiquette: string[];
  startDate: Date | null;
  endDate: Date | null;
};


//----------------

export type IColisColissimoItem = {
  id: string;
  trackingNumber: string;
  etiquetteCreatedAt: Date;
  orderCreatedAt: Date;
  country: string;
  shippingMethod: ShippingMethodType;
};



//-----------------

export type IHistoricBordereauColissimoItem = {
  id: string;
  colisNumber: number;
  orderIds: string[];
  trackingNumber: string;
  createdAt: Date;
};

//---------------

export type EmailConfig = {
  subject: string;
  description: string;
}

// ----------------------------------------------------------------------

export enum MethodMondialRelayType {
  PointVente = 'Point de vente',
  FlexibleShipping = 'Flexible Shipping',
  MondialRelayInPostOfficiel = 'Mondial Relay - InPost Officiel',
  NotApplicable = 'N/A',
}
export type IMethodMondialRelayItem = {
  id: string;
  name: string;
  type: MethodMondialRelayType;
  shippingArea: IShippingAreaItem;
  shippingMode: MondialRelayMode;
};


// ----------------------------------------------------------------------

export type IOrderMondialRelayItem = {
  id: string;
  status: IOrderMondialRelayStatus;
  shippingMode: MondialRelayMode;
  dateCreation: Date;
  expedition: string;
  address: string;
  weight: number;
  expeditionNumber: string;
  delivery: string;
};

export type IOrderMondialRelayTableFilterValue = string | string[] | Date | null;

export type IOrderMondialRelayTableFilters = {
  shippingMode: string[];
  status: string[];
  dateCreation: Date | null;
};

export enum IOrderMondialRelayStatus {
  WaitingForPayment = "Attente paiement",
  InProgress = "En cours",
  Pending = "En attente",
};

//-------------------------------

export type ExpeditionMondialRelayTableFilterValue = string | string[] | Date | null;

export type ExpeditionMondialRelayTableFilters = {
  shippingMode: string[];
  status: string[];
  startDate: Date | null;
  endDate: Date | null;
};