import { _mock } from "./_mock";
import { addDays } from "date-fns";
import { fDate } from "@/utils/format-time";

//------------------live---------------------------
export type ILiveItem = {
  id: string;
  title: string;
  description: string;
  startDate: Date;
  EditDate: Date;
  totalSales: number;
  nbrUser: number;
  nbrProdut: number;
  endDate: Date;
  productseen: number;
  productDelet: number;
  productPay: number;
  type: string;
};
export const LiveTyple = [
  { value: "Live", label: "Live" },
  { value: "Demande MP", label: "Demande MP" },
  { value: "Article a contrôlé", label: "Article a contrôlé" },
  { value: "Autre", label: "Autre" },
];

export type SalesSessionTableFilterValue = string | string[];

export type SalesSessionTableFilters = {
  title: string;
  type: string;
};

export const _livesInf = [...Array(20)].map((_, index) => ({
  id: `601${index}`,
  title: "live" + "#" + `601${index}`,
  description: _mock.postTitle(index),
  startDate: _mock.time(index),
  EditDate: addDays(_mock.time(index), 1),
  totalSales: _mock.number.nativeL(index) * 3,
  nbrUser: _mock.number.age(index),
  nbrProdut: _mock.number.age(index) * 2,
  endDate: addDays(_mock.time(index), 5),
  productseen: _mock.number.nativeL(index),
  productDelet: _mock.number.nativeS(index),
  productPay: _mock.number.nativeM(index),
  type:
    (index % 2 && "Article a contrôlé") ||
    (index % 3 && "Demande MP") ||
    (index % 4 && "Live") ||
    "Autre",
}));

//-------------------------Product----------------------------
export type IProduct = {
  id: string;
  image: string;
  title: string;
  description: string;
  price: number;
  quantity: number;
  createdAt: Date | string;
  colors: string[];
  sizes: string[];
  variations: Variation[];
  UGS: string | number;
};

export type Variation = {
  id: string;
  name: string;
  color: string;
  size: string;
  quantity: number;
  price: number;
  UGS: string | number;
  image: string;
};

export const _products = [...Array(10)].map((_, index) => {
  const colors = _mock.colors(index);
  const sizes = _mock.sizes(index);
  const variations: Variation[] = [];

  // Création des variations pour chaque couleur et taille
  colors.forEach((color) => {
    sizes.forEach((size) => {
      // Vérifier si une variation avec la même couleur et la même taille existe déjà
      const existingVariation = variations.find(
        (variation) => variation.color === color && variation.size === size
      );

      if (!existingVariation) {
        variations.push({
          id: `${_mock.number.nativeL(index)}_${size}`,
          name: `${_mock.productName(index)} - ${color} - ${size}`,
          color: color,
          size: size,
          quantity: _mock.number.nativeS(index),
          price: _mock.number.price(index),
          UGS: `${_mock.number.nativeS(index)}_${color}_${size}`,
          image: _mock.image.product(index),
        });
      }
    });
  });

  return {
    id: _mock.id(index),
    image: _mock.image.product(index),
    title: _mock.productName(index),
    description: _mock.sentence(index),
    price: _mock.number.price(index),
    quantity: _mock.number.nativeS(index),
    createdAt: fDate(_mock.time(index)),
    colors: colors,
    sizes: sizes,
    variations: variations,
    UGS: _mock.number.nativeL(index),
  };
});

//--------------------------User------------------------------------------

export type IUserItem = {
  id: string;
  name: string;
  email: string;
  image: string;
  pseudo: string;
  CreatedAt: Date | string;
  status: string;
  phone: string;
};

export const _User = [...Array(20)].map((_, index) => ({
  id: "[" + _mock.number.nativeL(index) + "]" + _mock.email(index),
  name: _mock.fullName(index),
  email: _mock.email(index),
  pseudo: _mock.pseudo(index),
  CreatedAt: fDate(_mock.time(index)),
  status: (index % 2 && "active") || (index % 3 && "banned") || "active",
  image: _mock.image.avatar(index),
  phone: _mock.phoneNumber(index),
}));

export type IUserTableFilterValue = string | string[];

export type IUserTableFilters = {
  name: string;
  status: string;
};

export const USER_STATUS_OPTIONS = [
  { value: "active", label: "Active" },
  { value: "banned", label: "Banned" },
];

//------------------------------Order----------------------------------

export type IOrder = {
  id: string;
  name: string;
  email: string;
  title: string;
  UGS: string | number;
  quantity: number;
  pseudo: string;
  CreatedAt: Date | string;
  EditDate: Date | string;
  price: number;
  statutPanier: string;
  statutOrder: string;
};

export const _Order = [...Array(20)].map((_, index) => ({
  id: "[" + _mock.number.nativeL(index) + "]" + _mock.email(index),
  name: _mock.fullName(index),
  email: _mock.email(index),
  pseudo: _mock.pseudo(index),
  CreatedAt: fDate(_mock.time(index)),
  title: _mock.productName(index),
  price: _mock.number.price(index),
  UGS: _mock.number.nativeL(index),
  EditDate: fDate(_mock.time(index)),
  quantity: _mock.number.nativeS(index),
  statutPanier:
    (index % 2 && "supprimer") || (index % 3 && "consulter") || "payer",
  statutOrder:
    (index % 2 && "En attente") || (index % 3 && "En cours") || "Terminée",
}));

export type OrderTableFilterValue = string | string[];

export type OrderTableFilters = {
  name: string;
  statutPanier: string;
};

export const Order_STATUS_OPTIONS = [
  { value: "consulter", label: "consulter" },
  { value: "supprimer", label: "supprimer" },
  { value: "payer", label: "payer" },
];

export const PRODUCT_COLOR_NAME_OPTIONS = [
  { value: "red", label: "Red" },
  { value: "blue", label: "Blue" },
  { value: "cyan", label: "Cyan" },
  { value: "green", label: "Green" },
  { value: "yellow", label: "Yellow" },
  { value: "violet", label: "Violet" },
  { value: "black", label: "Black" },
  { value: "white", label: "White" },
];

export type VariationTableFilterValue = string | string[];

export type VariationTableFilters = {
  name: string;
  color: string[];
  size: string[];
};
