import { ILive, ILiveComment } from "@/shared/types/live";
import { useMemo } from "react";
import { _lives, generateSingleLiveStatistics, generateStatisticsForLives } from "../_mock";

export function useGetLives(params: any[] = []) {
    const memoizedValue = useMemo(
        () => ({
            livesLoading: false,
            livesError: false,
            livesValidating: false,
            livesData: _lives,
        }),
        [...params]
    );

    return memoizedValue;
}


export function useGetLive(liveId: string) {
    const memoizedValue = useMemo(
        () => ({
            liveLoading: false,
            liveError: false,
            liveValidating: false,
            liveData: {
                id: liveId,
                title: 'New Live Session',
                moderator: 'John Doe',
                description: 'This is a description of the live session. Here you can outline the goals, topics, and key speakers.',
                date: new Date(),
                time: new Date(new Date().setHours(new Date().getHours() + 1)),
                tags: ['Education', 'Technology'],
                staging: false,
                chat: true,
                cache: false,
                externalVideo: true,
                image: null,
                videoFormat: 'portrait',
                products: []
            }
        }),
        [liveId]
    );

    return memoizedValue;
}


export function useGetSingleLiveStatistic(liveId: string) {
    const memoizedValue = useMemo(
        () => (
            {
                statsLoading: false,
                statsError: false,
                statsValidating: false,
                statsData: generateSingleLiveStatistics(10)
            }
        ),
        [liveId]
    );
    return memoizedValue;
}

export function useGetLivesStatistic(startDate: Date, endDate: Date, lives: string[]) {
    const memoizedValue = useMemo(
        () => (
            {
                statsLoading: false,
                statsError: false,
                statsValidating: false,
                statsData: generateStatisticsForLives(10)
            }
        ),
        [startDate, endDate, lives]
    );
    return memoizedValue;
}



export async function addLive(data: ILive) {
    console.log(data);
    await new Promise((resolve) => setTimeout(resolve, 500));
}

export async function editLive(liveId: string, data: ILive) {
    console.log(data);
    await new Promise((resolve) => setTimeout(resolve, 500));
}

export async function addCommentLive(commentData: ILiveComment) {

}