import { useMemo } from "react";
import useSWR from "swr";
import { _orders, userId } from "../_mock";
import { endpoints } from './server';
import { mutate, revalidateEvents } from "swr/_internal";
import { success } from "@/theme/palette";
import { IMedia } from "../types/media";
import { title } from "process";
import { Description } from "@mui/icons-material";
import { AxiosResponse } from "axios";
import axios, { AxiosRequestConfig } from 'axios';
import { HOST_API_MEDIA_LIBRARY } from '@/config-global';


export const axiosInstance = axios.create({ baseURL: HOST_API_MEDIA_LIBRARY });

axiosInstance.interceptors.response.use(
  (res) => res,
  (error) => Promise.reject((error.response && error.response.data) || 'Something went wrong')
);

export default axiosInstance;


export const fetcher = async (args: string | [string, AxiosRequestConfig]) => {
  const [url, config] = Array.isArray(args) ? args : [args];

  const res = await axiosInstance.get(url, { ...config });

  return res.data;
};


const options = {
    revalidateIfStale: false,
    revalidateOnFocus: false,
    revalidateOnReconnect: false,
}



///////////////////-----------Media Management----------///////////////////////
//////////////////////////////////////////////////////////////////////////////
export function useGetMedias() {
    const URL = [endpoints.media.getAll];
    const { data, error } = useSWR<IMedia[]>(URL, fetcher, options);

    const memoizedValue = useMemo(
        () => ({
            mediasData: (data as IMedia[]) || [],
            mediasError: error,
        }),
        [data, error]
    );

    return memoizedValue;
}

export function useGetMedia(mediaId: string) {
    const { data, error } = useSWR<IMedia>(
        mediaId ? endpoints.media.getById(mediaId) : null,
        fetcher
    );

    const memoizedValue = useMemo(
        () => ({
            mediaData: data,
            mediaError: error,
        }),
        [data, error]
    );

    return memoizedValue;
}

export const useUploadMedias = async (formData: FormData): Promise<void> => {
    try {
        let url = endpoints.media.add;

        formData.append('userId', userId);

        const response: AxiosResponse = await axiosInstance.post(url, formData, {
            headers: {
                'Content-Type': 'multipart/form-data',
            },
        });

        mutate(endpoints.media.getAll);

    } catch (error) {
        throw error;
    }
};

export async function useUpdateMedia(id: string, updatedMedia: any) {
    const formData = {
        id: updatedMedia.id,
        title: updatedMedia.title,
        description: updatedMedia.description,
        userId: updatedMedia.userId,
    }
    const response = await axiosInstance.put(endpoints.media.edit(id), formData);
    const updatedData: IMedia = response.data;
    mutate([endpoints.media.getAll], (medias: IMedia[] = []) =>
        medias.map((media) =>
            media.id === id ? updatedData : media
        ),
        true
    );
    return response.data as IMedia;
}

export async function useDeleteMedia(mediaIDs: string[]) {
    const response = await axiosInstance.delete(endpoints.media.delete(mediaIDs));
    mutate(endpoints.media.getAll);
    return response.status;
}

