import axios, { AxiosRequestConfig } from 'axios';
import { comment } from 'postcss';
import { shippingClassesList } from '../_mock/_shipping';


export const HOST_API = 'http://localhost:8081';

export const axiosInstance = axios.create({ baseURL: HOST_API });

axiosInstance.interceptors.response.use(
  (res) => res,
  (error) => Promise.reject((error.response && error.response.data) || 'Something went wrong')
);

export default axiosInstance;


export const fetcher = async (args: string | [string, AxiosRequestConfig]) => {
  const [url, config] = Array.isArray(args) ? args : [args];

  const res = await axiosInstance.get(url, { ...config });

  return res.data;
};


export const endpoints = {
  comments: {
    add: "/chat/message",
    get: (liveId:string) =>`/chat/stream/${liveId}`,
  },
  product: "/product",
  live : {
    stream: '/live',
    products : '/live-product',
    stats : {
      summaryAll : '/api/stats/summary',
      summary : (liveId:string) => `/api/stats/${liveId}/summary`,
      realTime : (keyStream:string) => `/api/stats/${keyStream}`,
    }
  },
  shipping:{
    shippingClass:{
      getAll: `/shipping/shipping-class`,
      getById:(shippingClassId:string)=> `/shipping/shipping-class/${shippingClassId}`,
      add: "/shipping/shipping-class",
      edit:(shippingClassId:string)=> `/shipping/shipping-class/${shippingClassId}`,
      delete:(shippingClassId:string)=> `/shipping/shipping-class/${shippingClassId}`,
    },
    shippingRules:{
      getById:(shippingRulesId:string)=> `/shipping/shipping-rules/${shippingRulesId}`,
      edit:(shippingRulesId:string)=> `/shipping/shipping-rules/${shippingRulesId}`,
    },
    shippingMethod:{
      getAll: `/shipping/shipping-method`,
      getById:(shippingMethodId:string)=> `/shipping/shipping-method/${shippingMethodId}`,
      delete:(shippingMethodId:string)=> `/shipping/shipping-method/${shippingMethodId}`,
      freeShipping:{
        getAll: `/shipping/method/free-shipping`,
        getById:(shippingMethodId:string)=> `/shipping/method/free-shipping/${shippingMethodId}`,
        add: "/shipping/method/free-shipping",
        edit:(shippingMethodId:string)=> `/shipping/method/free-shipping/${shippingMethodId}`,  
      },
      flatRate:{
        getAll: `/shipping/method/flat-rate`,
        getById:(shippingMethodId:string)=> `/shipping/method/flat-rate/${shippingMethodId}`,
        add: "/shipping/method/flat-rate",
        edit:(shippingMethodId:string)=> `/shipping/method/flat-rate/${shippingMethodId}`,  
      },
      pointOfSale:{
        getAll: `/shipping/method/point-of-sale`,
        getById:(shippingMethodId:string)=> `/shipping/method/point-of-sale/${shippingMethodId}`,
        add: "/shipping/method/point-of-sale",
        edit:(shippingMethodId:string)=> `/shipping/method/point-of-sale/${shippingMethodId}`,  
      },
      colissimo:{
        getAll: `/shipping/method/colissimo`,
        getById:(shippingMethodId:string)=> `/shipping/method/colissimo/${shippingMethodId}`,
        add: "/shipping/method/colissimo",
        edit:(shippingMethodId:string)=> `/shipping/method/colissimo/${shippingMethodId}`,  
      },
      mondialRelay:{
        getAll: `/shipping/method/mondial-relay`,
        getById:(shippingMethodId:string)=> `/shipping/method/mondial-relay/${shippingMethodId}`,
        add: "/shipping/method/mondial-relay",
        edit:(shippingMethodId:string)=> `/shipping/method/mondial-relay/${shippingMethodId}`,  
      },
    },
    shippingArea:{
      getAll: `/shipping/shipping-area`,
      getById:(shippingAreaId:string)=> `/shipping/shipping-area/${shippingAreaId}`,
      add: "/shipping/shipping-area",
      edit:(shippingAreaId:string)=> `/shipping/shipping-area/${shippingAreaId}`,
      delete:(shippingAreaId:string)=> `/shipping/shipping-area/${shippingAreaId}`,
    },
  },
  media:{
    getAll: `/api/medias/all-medias`,
    getById:(mediaId:string)=> `/api/medias/${mediaId}`,
    add: "/api/medias/upload-medias",
    edit:(mediaId:string)=> `/api/medias/update-media/${mediaId}`,
    delete:(mediaIDs:string[])=> `/api/medias/delete/${mediaIDs}`,
    download:(mediaId:string)=> `/api/medias/download`
  },
};
