"use client";
import React, { useState } from "react";
import {
  Card,
  CardContent,
  Typography,
  Button,
  TextField,
  Grid,
  Stack,
} from "@mui/material";
import { fDate, fTime } from "@/utils/format-time";
import { _livesInf, IProduct } from "@/shared/_mock/_cartLive";
import ProductListDialog from "./add-products";
import ProductVariationsCard from "./AllVariation/Product-Variation";
import AllUsersView from "./all-users/all-users-view";
import AllOrderView from "./all-Orders/all-orders-view";
import AllNewUsersView from "./all-NewUsers/All-NewUsers-view";
import AnalyticsWidgetSummary from "./statistics-widget-summary";
import CustomBreadcrumbs from "@/components/custom-breadcrumbs";
import { paths } from "@/routes/paths";

type Props = {
  liveId: string;
};

export default function LiveCard({ liveId }: Props) {
  const {
    id,
    description,
    startDate,
    EditDate,
    totalSales,
    nbrUser,
    endDate,
    productseen,
    productDelet,
    productPay,
  } = _livesInf[1];

  const [dialogOpen, setDialogOpen] = useState(false);
  const [selectedProduct, setSelectedProduct] = useState<IProduct | null>(null);

  const handleOpenDialog = () => {
    setDialogOpen(true);
  };

  const handleCloseDialog = () => {
    setDialogOpen(false);
  };

  const handleProductSelect = (selectedProduct: IProduct) => {
    setSelectedProduct(selectedProduct);
    setDialogOpen(false);
  };

  const renderDetails = () => (
    <Grid xs={12}>
      <Grid container spacing={3}>
        <Grid item xs={12} sm={6} md={4}>
          <AnalyticsWidgetSummary
            title="Nombre de produits vendus"
            total={totalSales}
            icon={<img alt="icon" src="/assets/icons/glass/ic_glass_bag.png" />}
          />
        </Grid>

        <Grid item xs={12} sm={6} md={4}>
          <AnalyticsWidgetSummary
            title="Nombre des clients"
            total={nbrUser}
            icon={
              <img alt="icon" src="/assets/icons/glass/ic_glass_users.png" />
            }
          />
        </Grid>

        <Grid item xs={12} sm={6} md={4}>
          <AnalyticsWidgetSummary
            title="Total vente"
            total={totalSales}
            icon={<img alt="icon" src="/assets/icons/glass/ic_glass_buy.png" />}
            showEuroSymbol={true}
          />
        </Grid>
        <Grid item xs={12} sm={6} md={4}>
          <AnalyticsWidgetSummary
            title="Produits consulté"
            total={productseen}
            icon={
              <img alt="icon" src="/assets/icons/glass/ic_glass_message.png" />
            }
          />
        </Grid>
        <Grid item xs={12} sm={6} md={4}>
          <AnalyticsWidgetSummary
            title="Produits supprimé"
            total={productDelet}
            icon={
              <img alt="icon" src="/assets/icons/glass/ic_glass_live.png" />
            }
          />
        </Grid>
        <Grid item xs={12} sm={6} md={4}>
          <AnalyticsWidgetSummary
            title="Produits payé"
            total={productPay}
            icon={<img alt="icon" src="/assets/icons/glass/ic_glass_buy.png" />}
          />
        </Grid>
      </Grid>

      <Card style={{ margin: "20px 0" }}>
        <CardContent>
          <Typography variant="subtitle2" color="textSecondary">
            Date de création:{" "}
            {fDate(startDate) + "  " + fTime(startDate).toString()}
          </Typography>
          <Typography variant="subtitle2" color="textSecondary">
            Dernière mise à jour:{" "}
            {fDate(EditDate) + "  " + fTime(EditDate).toString()}
          </Typography>

          <Typography variant="subtitle2" color="textSecondary">
            Description: {description}
          </Typography>
          <Typography variant="subtitle2" color="textSecondary">
            Date d'expiration :
          </Typography>
          <div
            style={{
              display: "flex",
              alignItems: "center",
              marginTop: "10px",
            }}
          >
            <TextField
              id="date-expiration"
              type="date"
              defaultValue={fDate(endDate)}
              InputLabelProps={{
                shrink: true,
              }}
              style={{ marginRight: "10px" }}
            />
            <Button variant="contained" color="primary">
              Modifier
            </Button>
          </div>
        </CardContent>
        <CardContent style={{ textAlign: "center" }}>
          <Button
            variant="contained"
            color="primary"
            onClick={handleOpenDialog}
          >
            Rechercher un produit
          </Button>
        </CardContent>
        <ProductListDialog
          open={dialogOpen}
          onClose={handleCloseDialog}
          onSelect={handleProductSelect}
          // onSelect={(product) => {
          //   console.log("Selected Product:", product);
          // }}
        />
      </Card>
    </Grid>
  );

  return (
    <div>
      <CustomBreadcrumbs
        heading={`Panier du live : ${liveId}`}
        links={[
          {
            name: "dashboard",
            href: paths.dashboard.root,
          },
          {
            name: "Tout les Panier",
            href: paths.dashboard.cart.root,
          },
          {
            name: "Panier",
          },
        ]}
        sx={{
          mb: { xs: 3, md: 5 },
        }}
      />
      <Stack
        direction="column"
        justifyContent="flex-start"
        alignItems="stretch"
        spacing={4}
      >
        {renderDetails()}
        {selectedProduct && <ProductVariationsCard product={selectedProduct} />}
        {AllUsersView()}
        {AllNewUsersView()}
        {AllOrderView()}
      </Stack>
    </div>
  );
}
