"use client";
import Container from "@mui/material/Container";
import { paths } from "@/routes/paths";
import { useSettingsContext } from "@/shared/components/settings";
import CustomBreadcrumbs from "@/components/custom-breadcrumbs";
import { Grid } from "@mui/material";
import { useState } from "react";
import { useGetLivesStatistic } from "@/shared/api/live";
import OrderFilters from "./statistics-filters";
import BasketAmountChart from "./EcartAmount-chart";
import SalesNetteChart from "./SalesNettechart";
import AnalyticsNetSales from "./ProductRateChart";
import AnalyticsAbandonedCarts from "./Analytics-AbandonedCarts";
import AppWidgetSummary from "./statistics-widget-summary";
import { useTheme } from "@mui/material/styles";
import BestSalesProduct from "./Best-salesProduct";
import { _BestSalesProduct } from "@/shared/_mock";

export default function AllStatisticsView() {
  const settings = useSettingsContext();
  const [startDate, setStartDate] = useState<Date>(new Date("2023-03-21"));
  const [endDate, setEndDate] = useState<Date>(new Date("2023-03-23"));
  const [selectedOrders, setSelectedOrders] = useState<string[]>([]);

  const {
    statsData: { stats },
  } = useGetLivesStatistic(startDate, endDate, selectedOrders);
  const theme = useTheme();

  const statsFiltersProps = {
    startDate,
    endDate,
    onChangeStartDate: (startDate: Date) => {
      setStartDate(startDate);
    },
    onChangeEndDate: (endDate: Date) => {
      setEndDate(endDate);
    },
    selectedOrders,
    setSelectedOrders,
  };

  return (
    <Container
      sx={{ gap: 3, display: "flex", flexDirection: "column" }}
      maxWidth={settings.themeStretch ? false : "lg"}
    >
      <CustomBreadcrumbs
        heading="Statistiques du Paniers"
        links={[
          {
            name: "dashboard",
            href: paths.dashboard.root,
          },
          {
            name: "Panier",
            href: paths.dashboard.cart.root,
          },
          {
            name: "Statistiques",
          },
        ]}
        sx={{
          mb: { xs: 3, md: 5 },
        }}
      />

      <OrderFilters {...statsFiltersProps} />
      <Grid container spacing={3}>
        <Grid item xs={12} sm={6} md={4}>
          <AppWidgetSummary
            title="Taux de transformation"
            percent={2.6}
            total={92}
            color={theme.palette.error.light}
            chart={{
              colors: [theme.palette.primary.main, theme.palette.primary.dark],
              series: [5, 18, 12, 51, 68, 11, 39, 37, 27, 20],
            }}
            showPercentage={true}
          />
        </Grid>

        <Grid item xs={12} sm={6} md={4}>
          <AppWidgetSummary
            title="Chiffre d'affaire réel"
            percent={0.2}
            total={7000}
            color={theme.palette.info.dark}
            chart={{
              colors: [theme.palette.warning.dark, theme.palette.warning.dark],
              series: [20, 41, 63, 33, 28, 35, 50, 46, 11, 26],
            }}
            showEuroSymbol={true}
          />
        </Grid>

        <Grid item xs={12} sm={6} md={4}>
          <AppWidgetSummary
            title="Chiffre d'affaire théorique"
            percent={0}
            total={7050}
            color={theme.palette.primary.main}
            chart={{
              colors: [theme.palette.info.dark, theme.palette.info.dark],
              series: [8, 9, 31, 8, 16, 37, 8, 33, 46, 31],
            }}
            showEuroSymbol={true}
          />
        </Grid>
      </Grid>
      <Grid container spacing={1}>
        <Grid item xs={4} md={4} lg={4}>
          <AnalyticsAbandonedCarts
            title="Paniers Abandonnés"
            chart={{
              series: [
                { label: "paniers créés", value: 600 },
                { label: "paniers abandonnés", value: 100 },
              ],
            }}
          />
        </Grid>
        <Grid item xs={8} md={6} lg={8}>
          <AnalyticsNetSales
            title="Taux d’ajout des produits au panier"
            chart={{
              labels: [
                "04/01/2024",
                "04/06/2024",
                "04/09/2024",
                "04/10/2024",
                "04/15/2024",
                "04/17/2024",
                "04/20/2024",
                "04/29/2024",
              ],
              series: [
                {
                  name: "Période précédente",
                  type: "line",
                  fill: "solid",
                  data: [230, 110, 220, 270, 130, 220, 370, 210],
                },
                {
                  name: "Année précédente",
                  type: "line",
                  fill: "solid",
                  data: [440, 550, 410, 670, 220, 430, 210, 970],
                },
                {
                  name: "Mois en cours",
                  type: "line",
                  fill: "solid",
                  data: [300, 250, 360, 300, 450, 350, 640, 520],
                },
              ],
            }}
          />
        </Grid>
      </Grid>
      <SalesNetteChart
        title="Montant total des ventes Nette"
        chart={{
          categories: [
            "01 avr",
            "05 avr",
            "15 avr",
            "20 avr",
            "25 avr",
            "27 avr",
            "29 avr",
            "30 avr",
          ],
          series: [
            {
              type: "Période précédente",
              data: [
                {
                  name: "Montant de la période précédente",
                  data: [
                    10000, 41000, 35000, 151000, 49000, 62000, 69000, 91000,
                  ],
                },
              ],
            },
            {
              type: "Année précédente",
              data: [
                {
                  name: "Montant de l'année précédente ",
                  data: [
                    148000, 91000, 69000, 62000, 49000, 51000, 35000, 41000,
                  ],
                },
              ],
            },
            {
              type: "Mois en cours",
              data: [
                {
                  name: "Montant total en cours",
                  data: [
                    76000, 42000, 29000, 41000, 27000, 138000, 117000, 86000,
                  ],
                },
              ],
            },
          ],
          options: {
            yaxis: {
              title: {
                text: "Mantant",
              },
              min: 0,
              max: 100000,
              labels: {
                formatter: (value: number) => {
                  if (value >= 1000) {
                    return `${(value / 1000).toFixed(0)}K€`;
                  } else {
                    return `${value}€`;
                  }
                },
              },
            },
          },
        }}
      />
      <BasketAmountChart
        title="Écart entre montant théorique et montant réel des paniers"
        chart={{
          categories: ["avr", "mai", "Juin", "juil", "août"],
          series: [
            {
              type: "Mois en cours",
              data: [
                {
                  name: "Montant théorique",
                  data: [10000, 20000, 30000, 40000, 50000],
                },
              ],
            },
            {
              type: "Montant réel des paniers",
              data: [
                {
                  name: "Montant réel",
                  data: [9000, 19000, 28000, 37000, 45000],
                },
              ],
            },
            {
              type: "Période précédente",
              data: [
                {
                  name: "Montant théorique",
                  data: [10500, 20500, 28500, 37500, 70500],
                },
              ],
            },
            {
              type: "Période précédente",
              data: [
                {
                  name: "Montant réel",
                  data: [20500, 30500, 28500, 37500, 70500],
                },
              ],
            },
            {
              type: "Année précédente",
              data: [
                {
                  name: "Montant théorique",
                  data: [9000, 19000, 28000, 77000, 85000],
                },
              ],
            },
            {
              type: "Année précédente",
              data: [
                {
                  name: "Montant réel",
                  data: [10000, 20000, 30000, 77000, 85000],
                },
              ],
            },
          ],
          options: {
            yaxis: {
              title: {
                text: "Montant",
              },
              min: 0,
              max: 100000,
              labels: {
                formatter: (value: number) => {
                  if (value >= 1000) {
                    return `${(value / 1000).toFixed(0)}K€`;
                  } else {
                    return `${value}€`;
                  }
                },
              },
            },
          },
        }}
      />
      <Grid xs={12} md={6} lg={8}>
        <BestSalesProduct
          title="Les Produits les plus vendus"
          tableData={_BestSalesProduct}
          tableLabels={[
            { id: "name", label: "Produits" },
            { id: "category", label: "Catégorie" },
            { id: "totalAmount", label: "Chiffre D'affaire", align: "right" },
            { id: "rank", label: "Rank", align: "right" },
          ]} tableData1={[]}        />
      </Grid>
    </Container>
  );
}
