import React from 'react';
import Table from "@mui/material/Table";
import Avatar from "@mui/material/Avatar";
import TableRow from "@mui/material/TableRow";
import TableCell from "@mui/material/TableCell";
import TableBody from "@mui/material/TableBody";
import CardHeader from "@mui/material/CardHeader";
import Card, { CardProps } from "@mui/material/Card";
import TableContainer from "@mui/material/TableContainer";

import { fCurrency } from "@/utils/format-number";

import Label from "@/shared/components/label";
import Scrollbar from "@/components/scrollbar";
import { TableHeadCustom } from "@/shared/components/table";

// ----------------------------------------------------------------------

type RowProps = {
  id: string;
  name: string;
  rank: string;
  category: string;
  avatarUrl: string;
  totalAmount: number;
};

type SalesData = {
  date: string;
  totalAmount: number;
  
};

interface Props extends CardProps {
  title?: string;
  subheader?: string;
  tableData: RowProps[];
  tableData1: SalesData[];
  tableLabels: any;
}

export default function BestSalesProduct({
  title,
  subheader,
  tableData,
  tableData1,
  tableLabels,
  ...other
}: Props) {
  return (
    <Card {...other}>
      <CardHeader title={title} subheader={subheader} sx={{ mb: 3 }} />

      <TableContainer sx={{ overflow: "unset" }}>
        <Scrollbar>
          <Table sx={{ minWidth: 640 }}>
            <TableHeadCustom headLabel={tableLabels} />

            <TableBody>
              {tableData.map((row) => (
                <EcommerceBestSalesmanRow key={row.id} row={row} />
              ))}
              {tableData1.map((row, index) => (
                <SalesDataRow key={index} row={row} />
              ))}
            </TableBody>
          </Table>
        </Scrollbar>
      </TableContainer>
    </Card>
  );
}

// ----------------------------------------------------------------------

type EcommerceBestSalesmanRowProps = {
  row: RowProps;
};

function EcommerceBestSalesmanRow({ row }: EcommerceBestSalesmanRowProps) {
  return (
    <TableRow>
      <TableCell sx={{ display: "flex", alignItems: "center" }}>
        <Avatar alt={row.name} src={row.avatarUrl} sx={{ mr: 2 }} />
        {row.name}
      </TableCell>

      <TableCell>{row.category}</TableCell>

      <TableCell align="right">{fCurrency(row.totalAmount)}</TableCell>

      <TableCell align="right">
        <Label
          variant="soft"
          color={
            (row.rank === "Top 1" && "primary") ||
            (row.rank === "Top 2" && "info") ||
            (row.rank === "Top 3" && "success") ||
            (row.rank === "Top 4" && "warning") ||
            "error"
          }
        >
          {row.rank}
        </Label>
      </TableCell>
    </TableRow>
  );
}

type SalesDataRowProps = {
  row: SalesData;
};

function SalesDataRow({ row }: SalesDataRowProps) {
  return (
    <TableRow>
      <TableCell>{row.date}</TableCell>
      <TableCell align="right">{fCurrency(row.totalAmount)}</TableCell>
    </TableRow>
  );
}
