import React from 'react';
import Table from "@mui/material/Table";
import TableRow from "@mui/material/TableRow";
import TableCell from "@mui/material/TableCell";
import TableBody from "@mui/material/TableBody";
import CardHeader from "@mui/material/CardHeader";
import Card, { CardProps } from "@mui/material/Card";
import TableContainer from "@mui/material/TableContainer";
import { fCurrency } from "@/utils/format-number";
import Scrollbar from "@/components/scrollbar";
import { TableHeadCustom } from "@/shared/components/table";

type SalesData = {
  date: string;
  totalAmount: number;
  product: string;
};

interface Props extends CardProps {
  title?: string;
  subheader?: string;
  tableData1: SalesData[];
  tableLabels: any;
}

export default function Sessionlive({
  title,
  subheader,
  tableData1,
  tableLabels,
  ...other
}: Props) {
  return (
    <Card {...other}>
      <CardHeader title={title} subheader={subheader} sx={{ mb: 3 }} />
      <TableContainer sx={{ overflow: "unset" }}>
        <Scrollbar>
          <Table sx={{ minWidth: 640 }}>
            <TableHeadCustom headLabel={tableLabels} />
            <TableBody>
              {tableData1.map((row, index) => (
                <SalesDataRow key={index} row={row} />
              ))}
            </TableBody>
          </Table>
        </Scrollbar>
      </TableContainer>
    </Card>
  );
}

type SalesDataRowProps = {
  row: SalesData;
};

function SalesDataRow({ row }: SalesDataRowProps) {
  return (
    <TableRow>
      <TableCell>{row.date}</TableCell>
      <TableCell >{fCurrency(row.totalAmount)}</TableCell>
      <TableCell>{row.product}</TableCell>
    </TableRow>
  );
}
