import { sub } from 'date-fns';
import { useMemo, useState, useCallback } from 'react';

import InputBase from '@mui/material/InputBase';
import IconButton from '@mui/material/IconButton';
import { useResponsive, useRouter } from '@/hooks';
import uuidv4 from '@/utils/uuidv4';
import InputEmoji from 'react-input-emoji'
import Iconify from '@/components/iconify';
import { addCommentLive } from '@/shared/api/live';
import { Paper, useTheme } from '@mui/material';



type Props = {
    liveId: string;
    disabled: boolean;
};

export default function CommentsInput({
    liveId,
    disabled
}: Props) {
    const router = useRouter();
    const [comment, setComment] = useState('');
    const theme = useTheme();
    const mdUp = useResponsive('up', 'md');

    const style = mdUp ? {
        left: '50%',
    } : {
        left: '51%',
    };
    const commentData = useMemo(
        () => ({
            id: uuidv4(),
            attachments: [],
            body: comment,
            createdAt: sub(new Date(), { minutes: 1 }),
            senderId: 'admin',
            live: liveId
        }),
        [comment]
    );

    const conversationData = useMemo(
        () => ({
            id: uuidv4(),
            messages: [commentData],
        }),
        [commentData,]
    );



    const handleChangeComment = useCallback((event: React.ChangeEvent<HTMLInputElement>) => {
        setComment(event.target.value);
    }, []);

    const handleSendComment = useCallback(
        async (event: React.KeyboardEvent<HTMLInputElement>) => {
            try {
                if (event.key === 'Enter') {
                    if (comment) {
                        await addCommentLive(commentData);
                        setComment('');
                    }
                }

            } catch (error) {
                console.error(error);
            }
        },
        [conversationData, comment, commentData, router, liveId]
    );

    return (
        <Paper style={{
            zIndex: 2,
            flexShrink: 0,
            display: 'flex',
            alignItems: 'center',
            justifyContent: 'center',
            background: 'transparent',
            borderRadius: 2,
            width: '98%',
            ...style,
            position: 'absolute',
            transform: 'translateX(-50%)',
            bottom: 0,
            paddingRight:4,
        }}>
            <InputEmoji
                value={comment}
                cleanOnEnter
                onChange={(value) => setComment(value)}
                placeholder="Type a message"
                height={20}
            />
            <Iconify style={{height:30, width:30, color: 'gray', marginBottom:2}} icon="iconamoon:send-fill" />
        </Paper>
    );
}
