import { formatDistanceToNowStrict } from 'date-fns';

import Stack from '@mui/material/Stack';
import IconButton from '@mui/material/IconButton';
import Typography from '@mui/material/Typography';


import Iconify from '@/components/iconify';

import { ILiveComment } from '@/shared/types/live';
import { Card, useTheme, alpha } from '@mui/material';
import { bgGradient } from '@/shared/theme/css';
import { useResponsive } from '@/hooks';



type Props = {
  comment: ILiveComment;

};

export default function LiveCommentItem({ comment }: Props) {

  const { body, createdAt, senderId, } = comment;
  const theme = useTheme();
  const mdUp = useResponsive('up', 'md');
  const bgStyle = mdUp ? {
    ...bgGradient({

      direction: '135deg',
      startColor: alpha(theme.palette['primary'].light, 0.2),
      endColor: alpha(theme.palette['primary'].main, 0.2),
    }),
    width: "100%",
    p: .5,
    fontSize: theme.typography.pxToRem(12),
  } : {
    fontSize: theme.typography.pxToRem(12),
    backgroundColor: 'rgb(0 0 0 / 50%)',
    color: 'white',
    borderColor: 'gray',
    textDecorationColor: 'gray',
    width: 200,
    p: .5,
  };

  const renderInfo = (
    <Typography
      noWrap
      variant="caption"
      sx={{
        mr: 'auto',
        color: 'grey'
      }}
    >
      {`${senderId},`} &nbsp;
      {mdUp && formatDistanceToNowStrict(new Date(createdAt), {
        addSuffix: true,
      })}
    </Typography>
  );

  const renderBody = (
    <Card
      sx={{
        
        borderRadius: 1,
        ...bgStyle,
      }}
    >

      {body}
    </Card>
  );

  const renderActions = (
    <Stack
      direction="row"
      className="message-actions"
      sx={{
        pt: 0.5,
        opacity: 0,
        bottom: '100%',
        right: 1,
        position: 'absolute',
        transition: (theme) =>
          theme.transitions.create(['opacity'], {
            duration: theme.transitions.duration.shorter,
          }),
      }}
    >
      <IconButton size="small">
        <Iconify icon="solar:reply-bold" width={16} />
      </IconButton>
      <IconButton size="small">
        <Iconify icon="eva:smiling-face-fill" width={16} />
      </IconButton>
      <IconButton size="small">
        <Iconify icon="mdi:pin" width={16} />
      </IconButton>
    </Stack>
  );

  return (
    <Stack direction="column" justifyContent={'unset'} sx={{ mb: 2 }}>
      <Stack alignItems="flex-end">
        {renderInfo}

        
      </Stack>
      <Stack
          direction="row"
          alignItems="flex-end"
          sx={{
            position: 'relative',
            '&:hover': {
              '& .message-actions': {
                opacity: 1,
              },
            },
          }}
        >
          {renderBody}
          {renderActions}
        </Stack>
    </Stack>
  );
}
