import { useMemo } from 'react';

import { Box } from '@mui/material';
import {generateCommentsForLive } from '@/shared/_mock';
import Scrollbar from '@/shared/components/scrollbar';
import LiveCommentItem from './details-comments-item';
import useScroll from '@/hooks/use-scroll';
import { ILiveComment } from '@/shared/types/live';



type Props = {
  liveId: string;
};

export default function CommentsList({
  liveId,
}: Props) {
  const comments = useMemo(() => {
    return generateCommentsForLive(10, liveId)
  }, [liveId])


  const {endRef:commentsEndRef } = useScroll<ILiveComment>(comments);





  return (
    <>
      <Scrollbar ref={commentsEndRef} sx={{ px: 2, py: 5, height:1, color: 'transparent'}}>
        <Box >
          {comments.map((comment) => (
            <LiveCommentItem
              key={comment.id}
              comment={comment}
            />
          ))}
        </Box>
      </Scrollbar>

    </>
  );
}

