import CustomBreadcrumbs from "@/components/custom-breadcrumbs";
import Iconify from "@/components/iconify";
import { useResponsive, useRouter } from "@/hooks";
import { paths } from "@/routes/paths";
import RouterLink from "@/routes/router-link";
import Label from "@/shared/components/label";
import { fDateTime } from "@/utils/format-time";
import { Button, IconButton, Paper, Stack, TextField, Typography } from "@mui/material";
import { TimeField } from "@mui/x-date-pickers";
import dayjs from 'dayjs';
import { useCallback } from "react";

export default function HeadSection({ liveId }: { liveId: string }) {
    const smUp = useResponsive('up', 'sm');
    const router=useRouter();
    const navigateToLives=useCallback(
        () => {
          router.push(paths.dashboard.live.root);
        },
        [router]
      );

    return (
        <Paper
            sx={{
                position: 'relative',
                display: 'flex',
                flexDirection: { xs: "column", lg: "row" },
                mb: 4,
                justifyContent: 'space-between',
                alignItems: { xs: "start", lg: "center" },
                gap: 2,
                width: "100%",
                bgcolor: "transparent"
            }}>

            <Stack width={300} direction="row" alignItems="flex-start">
                <IconButton onClick={navigateToLives} >
                    <Iconify icon="eva:arrow-ios-back-fill" />
                </IconButton>

                <Stack spacing={0.5}>
                    <Stack spacing={1} direction="row" alignItems="center">
                        <Typography variant="h4"> Live  #{liveId} </Typography>
                        <Label
                            variant="soft"
                            color={
                               
                                'success'
                            }
                        >
                            a venir
                        </Label>
                    </Stack>

                    <Typography variant="body2" sx={{ color: 'text.disabled' }}>
                        {fDateTime(new Date())}
                    </Typography>
                </Stack>
            </Stack>
            <Stack
                spacing={3}
                justifyContent={{ xs: 'center', md: 'flex-end' }}
                alignItems={'center'}
                direction={'row'}
                height={"100%"}
            >
                <TextField
                    label="Spectateur"
                    size="small"
                    variant="outlined"
                    sx={{ maxWidth: 100 }}
                    value={0}
                />
                {smUp && <TextField
                    label="Ajout au panier"
                    size="small"
                    variant="outlined"
                    sx={{ maxWidth: 110 }}
                    value={0}
                />}


                <TimeField
                    value={dayjs('2022-04-17T00:00').toDate()}
                    format="HH:mm:ss"
                    label="live"
                    size="small"
                    variant="outlined"
                    sx={{ maxWidth: 100 }}
                />
                <Button
                    component={RouterLink}
                    href={paths.dashboard.live.new}
                    variant="contained"
                    startIcon={<Iconify icon="material-symbols:not-started-rounded" />}
                >
                    {smUp && "Démarrer"}
                </Button>
                <Button
                    component={RouterLink}
                    href={paths.dashboard.live.new}
                    variant="contained"
                    startIcon={<Iconify icon="material-symbols-light:text-select-move-back-word" />}
                >
                    {smUp && "Quitter"}
                </Button>
            </Stack>


        </Paper>
    )
}