import React from 'react';
import {
    Avatar,
    Box,
    Button,
    Card,
    Grid,
    ListItemText,
    useTheme,
} from '@mui/material';
import { IProduct } from '@/shared/_mock';
import { TimeField } from '@mui/x-date-pickers';
import Iconify from '@/components/iconify';
import { paths } from '@/routes/paths';
import RouterLink from '@/routes/router-link';

const ProductCard = (product: IProduct) => {
    const theme = useTheme();
    return (
        <Card variant="outlined" sx={{ marginBottom: 2, bgcolor: theme.palette.background.neutral }}>

            <Grid container >
                <Grid item xs={4}  alignItems="flex-start"  >
                    <Avatar   variant="rounded" sx={{ height: "100%", width: "100%" }} alt={product.title} src={product.image} />
                </Grid >
                <Grid item xs={8}   sx={{ p:1, gap:2 , display: "flex" , flexDirection: "column",  }} padding={2}>
                    <ListItemText
                        primary={product.title}
                        secondary={product.reference}
                        primaryTypographyProps={{ typography: 'body2', noWrap: true }}
                        secondaryTypographyProps={{
                            mt: 0.5,
                            component: 'span',
                            typography: 'caption',
                        }}
                    />
                    <Box sx={{ display: 'flex', width: "100%",justifyContent:"space-between" , gap:2}}>
                        <Button
                            variant="contained"
                            fullWidth={true}
                            startIcon={<Iconify icon="mdi:add-bold" />}
                        >
                            Ajouter
                        </Button>
                        <Button
                            variant="contained"
                            fullWidth={true}
                            startIcon={<Iconify icon="ic:round-delete" />}
                        >
                            supprimer
                        </Button>
                    </Box>
                    <Box sx={{ display: 'flex', width: "100%",justifyContent:"space-between" ,gap:2}}>
                    <TimeField
                        fullWidth
                        size='small'
                        label="Start Time"
                        InputLabelProps={{
                            shrink: true,
                        }}
                        inputProps={{
                            step: 1, // Allows for second precision
                        }}
                    />
                    <TimeField
                        fullWidth
                        size='small'
                        label="End Time"
                        InputLabelProps={{
                            shrink: true,
                        }}
                        inputProps={{
                            step: 1, // Allows for second precision
                        }}
                    />
                    </Box>
                </Grid>
               
            </Grid>
        </Card>
    )
};

export default ProductCard;
