import { useResponsive } from "@/hooks/use-responsive";
import { Box, Button, Card, Grid, IconButton, List, Modal, TextField, styled } from "@mui/material";
import { _products } from '@/shared/_mock/_live';
import ProductCard from "./details-product-card";
import Scrollbar from "@/shared/components/scrollbar";
import SearchIcon from '@mui/icons-material/Search';
import useScroll from "@/hooks/use-scroll";
import { useState } from "react";


type Props = {
    liveId: string
}

export default function ProductsSection({ liveId }: Props) {
    const lgUp = useResponsive('up', 'lg');
    const { endRef: productsEndRef } = useScroll(_products);
    const [open, setOpen] = useState(false)
    function handleClose() {
        setOpen(false);
    };
    function handleOpen() {
        setOpen(true);
    };
    return (
        <>
            {lgUp ? (
                <Grid item lg={4} md={6} xs={12}>
                    <TextField
                        placeholder="Rechercher un nom de produit ou un SKU"
                        InputProps={{
                            endAdornment: (
                                <IconButton >
                                    <SearchIcon />
                                </IconButton>
                            ),
                        }}
                        variant="outlined"
                        fullWidth
                        sx={{ mb: 2 }}
                    />
                    <Card sx={{ height: 532 }}>
                        <Scrollbar ref={productsEndRef} sx={{ px: 2, py: 5, height: 1 }}>
                            {_products.map((product) => (
                                <ProductCard key={product.id} {...product} />
                            ))}
                        </Scrollbar>
                    </Card>
                </Grid>
            ) : (
                <>
                    <Button variant="outlined" onClick={handleOpen} sx={{ position: 'absolute', color: 'white', zIndex: 2, top: 20, left: 20 }}>Products</Button>
                    <Modal
                        open={open}
                        onClose={handleClose}
                        aria-labelledby="modal-modal-title"
                        aria-describedby="modal-modal-description"
                    >
                        <Card sx={{
                            position: 'absolute',
                            top: '50%',
                            left: '50%',
                            transform: 'translate(-50%, -50%)',
                            height: '80vh',
                            minWidth: '400px',
                            overflow: 'hidden',
                            display: 'flex',
                            flexDirection: 'column',
                            boxShadow: 24,
                        }}>
                            <TextField
                                placeholder="Rechercher un nom de produit ou un SKU"
                                InputProps={{
                                    endAdornment: (
                                        <IconButton >
                                            <SearchIcon />
                                        </IconButton>
                                    ),
                                }}
                                variant="outlined"
                                fullWidth
                                sx={{ mb: 2 }}
                            />
                            <Scrollbar ref={productsEndRef} sx={{ px: 2, py: 5, height: 1, overflowY: 'auto' }}>
                                <Box>
                                    {_products.map((product) => (
                                        <ProductCard  {...product} />
                                    ))}
                                </Box>
                            </Scrollbar>
                        </Card>
                    </Modal>
                </>
            )}
        </>
    )
}