import Button from "@mui/material/Button";
import MenuItem from "@mui/material/MenuItem";
import TableRow from "@mui/material/TableRow";
import Checkbox from "@mui/material/Checkbox";
import TableCell from "@mui/material/TableCell";
import IconButton from "@mui/material/IconButton";
import ListItemText from "@mui/material/ListItemText";

import { useBoolean } from "@/hooks/use-boolean";

import Label from "../../../components/label";
import Iconify from "@/components/iconify";
import { ConfirmDialog } from "../../../components/custom-dialog";
import CustomPopover, { usePopover } from "../../../components/custom-popover";

import { _livesInf, ILiveItem } from "@/shared/_mock/_cartLive";
import { fDate, fTime } from "@/utils/format-time";
import { Tooltip } from "@mui/material";
import ShoppingCartIcon from "@mui/icons-material/ShoppingCart";
import { useCallback } from "react";
import { useRouter } from "@/hooks";
import { paths } from "@/routes/paths";
// ----------------------------------------------------------------------

type Props = {
  selected: boolean;
  onEditRow: VoidFunction;
  row: ILiveItem;
  onSelectRow: VoidFunction;
  onDeleteRow: VoidFunction;
};

export default function SalesSessionTableRow({
  row,
  selected,
  onSelectRow,
  onDeleteRow,
}: Props) {
  const {
    id,
    title,
    startDate,
    EditDate,
    totalSales,
    nbrUser,
    nbrProdut,
    endDate,
    type,
    description,
  } = row;

  const confirm = useBoolean();

  const popover = usePopover();
  const router = useRouter();

  const handelPanier = useCallback(() => {
    router.push(paths.dashboard.live.panier(id));
  }, [router, id]);

  return (
    <>
      <TableRow hover selected={selected} onClick={handelPanier}>
        <TableCell sx={{ whiteSpace: "nowrap" }}>{id}</TableCell>

        <TableCell sx={{ whiteSpace: "nowrap" }}>{title}</TableCell>
        <TableCell>
          <ListItemText
            primary={fDate(startDate)}
            secondary={fTime(startDate)}
            primaryTypographyProps={{ typography: "body2", noWrap: true }}
            secondaryTypographyProps={{
              mt: 0.5,
              component: "span",
              typography: "caption",
            }}
          />
        </TableCell>
        <TableCell>
          <ListItemText
            primary={fDate(EditDate)}
            secondary={fTime(EditDate)}
            primaryTypographyProps={{ typography: "body2", noWrap: true }}
            secondaryTypographyProps={{
              mt: 0.5,
              component: "span",
              typography: "caption",
            }}
          />
        </TableCell>

        <TableCell sx={{ whiteSpace: "nowrap" }}>{nbrProdut}</TableCell>
        <TableCell sx={{ whiteSpace: "nowrap" }}>{nbrUser}</TableCell>
        <TableCell sx={{ whiteSpace: "nowrap" }}>{totalSales}</TableCell>
        <TableCell>
          <ListItemText
            primary={fDate(endDate)}
            secondary={fTime(endDate)}
            primaryTypographyProps={{ typography: "body2", noWrap: true }}
            secondaryTypographyProps={{
              mt: 0.5,
              component: "span",
              typography: "caption",
            }}
          />
        </TableCell>
        <TableCell sx={{ whiteSpace: "nowrap" }}>{description}</TableCell>
        <TableCell>
          <Label
            variant="soft"
            color={
              (type === "Live" && "success") ||
              (type === "Demande MP" && "warning") ||
              (type === "Article a contrôlé" && "error") ||
              (type === "Autre" && "default") ||
              "default"
            }
          >
            {type}
          </Label>
        </TableCell>

        <TableCell
          align="right"
          sx={{ px: 1, whiteSpace: "nowrap" }}
          onClick={(e) => e.stopPropagation()}
        >
          <Tooltip title="Panier">
            <IconButton sx={{ color: "#00e676" }} onClick={handelPanier}>
              <ShoppingCartIcon />
            </IconButton>
          </Tooltip>
        </TableCell>
      </TableRow>
    </>
  );
}
