"use client"

import Chart, { useChart } from '@/components/chart';
import Container from '@mui/material/Container';
import { paths } from '@/routes/paths';
import { useSettingsContext } from '@/shared/components/settings';
import CustomBreadcrumbs from '@/components/custom-breadcrumbs';
import { Card, Grid } from "@mui/material";
import AnalyticsWidgetSummary from "./statistics-widget-summary";
import { useMemo } from "react";
import { useGetSingleLiveStatistic } from "@/shared/api/live";



type Props = {
    liveId: string;
}

export default function SingleLiveStatistics({ liveId }: Props) {
    const settings = useSettingsContext();
    const { statsData: { statistics, totalViewers, totalMessages, totalCartAdditions } } = useGetSingleLiveStatistic(liveId);
    const series = useMemo(() => [{
        name: 'Specatateurs',
        data: statistics.map((stat) => ({ x: stat.timestamp, y: stat.viewerCount })),
    }, {
        name: 'Messages',
        data: statistics.map((stat) => ({ x: stat.timestamp, y: stat.messageCount })),
    }, {
        name: 'Ajouts au panier',
        data: statistics.map((stat) => ({ x: stat.timestamp, y: stat.cartAdditionCount })),
    }], [liveId]);

    const chartOptions = useChart({
        xaxis: {
            type: 'datetime',
        },
        yaxis: {
            title: {
                text: 'Count',
            },
        },
        tooltip: {
            x: {
                format: 'dd/MM/yy HH:mm',
            },
        },

    });

    return (
        <Container sx={{ gap: 4 }} maxWidth={settings.themeStretch ? false : 'lg'}>
            <CustomBreadcrumbs
                heading={`Statistiques du live : ${liveId}`}
                links={[
                    {
                        name: 'dashboard',
                        href: paths.dashboard.root,
                    },
                    {
                        name: 'lives',
                        href: paths.dashboard.live.all_lives,
                    },
                    {
                        name: 'Statistiques',
                    },
                ]}
                sx={{
                    mb: { xs: 3, md: 5 },
                }}
            />
            <Grid container spacing={3}>
                <Grid item xs={16} sm={8} md={4}>
                    <AnalyticsWidgetSummary
                        title="Messages"
                        total={totalMessages}
                        icon={<img alt="icon" src="/assets/icons/glass/ic_glass_message.png" />}
                    />
                </Grid>

                <Grid item xs={16} sm={8} md={4}>
                    <AnalyticsWidgetSummary
                        title="Spectateurs"
                        total={totalViewers}
                        color="info"
                        icon={<img alt="icon" src="/assets/icons/glass/ic_glass_users.png" />}
                    />
                </Grid>

                <Grid item xs={16} sm={8} md={4}>
                    <AnalyticsWidgetSummary
                        title="Ajouts au panier"
                        total={totalCartAdditions}
                        color="warning"
                        icon={<img alt="icon" src="/assets/icons/glass/ic_glass_buy.png" />}
                    />
                </Grid>
            </Grid>

            <Card sx={{ p: 4, marginTop: 4 }}>
                <Chart options={chartOptions} series={series} type="line" height={350} />
            </Card>
        </Container>)
        ;
};

