"use client";
import React, { useState } from "react";
import {
  Grid,
  Card,
  CardHeader,
  Stack,
  InputAdornment,
  FormControlLabel,
  Switch,
  Chip,
  Divider,
  Typography,
  TextField,
  Select,
  MenuItem,
  Autocomplete,
  IconButton,
  TableContainer,
  Table,
  TableHead,
  TableRow,
  TableCell,
  TableBody,
  Paper,
  Button,
  styled,
  Dialog,
  DialogTitle,
  DialogContent,
  DialogContentText,
  Tooltip,
  Alert,
  AlertTitle,
  Box,
} from "@mui/material";
import LoadingButton from "@mui/lab/LoadingButton";
import CustomBreadcrumbs from "@/components/custom-breadcrumbs/custom-breadcrumbs";
import { paths } from "@/routes/paths";
import { LocalizationProvider } from "@mui/x-date-pickers";
import DialogActions from "@mui/material/DialogActions";
import ProductForm from "../productForm";
import { useForm, SubmitHandler, Controller } from "react-hook-form";
import { yupResolver } from "@hookform/resolvers/yup";
import * as Yup from "yup";
import Iconify from "@/components/iconify";
import { OrderStatus } from "@/shared/_mock";
import { IOrderStatus } from "@/shared/types/order";

interface FormValues {}
type OrderEditViewProps = {
  id: string;
};

export default function OrderEditView({ id }: OrderEditViewProps) {
  const options = [
    "En attente",
    "En cours",
    "Terminée",
    "Annulée",
    "Remboursée",
    "Supprimée",
  ];
  const note = ["privée", "au client"];
  const clients = ["client 1"];

  const isOrderCompleted = OrderStatus.some(
    (status) => status === IOrderStatus.Completed
  );

  function createData(
    Article: string,
    Coût: number,
    Qte: number,
    Total: number
  ) {
    return { Article, Coût, Qte, Total };
  }
  const [open, setOpen] = React.useState(false);

  const handleClickOpen = () => {
    setOpen(true);
  };

  const handleClose = () => {
    setOpen(false);
  };
  const validationSchema = Yup.object().shape({
    etat: Yup.string().required("État est requis"),
    client: Yup.string().required("Client est requis"),
  });
  const {
    handleSubmit,
    control,
    formState: { errors },
  } = useForm({ resolver: yupResolver(validationSchema) });
  const onSubmit: SubmitHandler<FormValues> = (data) => {
    console.log(data);
  };
  const [orderItems, setOrderItems] = useState([
    createData("Article 1", 19, 2, 38),
    createData("Article 2", 15, 1, 15),
  ]);
  
  const handleRefundClick = () => {
    setIsRefundClicked(true);
    setIsCancelClicked(false);
  };
  
  const handleRefund = () => {
    console.log("Remboursement effectué avec succès !");
    setRefundAmount("");
    setRefundReason("");
    setIsRefundClicked(false);
  };
  
  const [isRefundClicked, setIsRefundClicked] = useState(false);
  const [isCancelClicked, setIsCancelClicked] = useState(false);
  const [refundAmount, setRefundAmount] = useState("");
  const [refundReason, setRefundReason] = useState("");
  

  const handleCancelClick = () => {
    setIsCancelClicked(true);
    setIsRefundClicked(false);
    setRefundAmount("");
    setRefundReason("");
  };

  
  const handleQuantityChange = (index: number, value: string) => {
    const newOrderItems = [...orderItems];
    newOrderItems[index].Qte = Number(value);
    setOrderItems(newOrderItems);
  };
  

  return (
    <>
      <LocalizationProvider>
        <CustomBreadcrumbs
          heading="Modifier une commande"
          links={[
            {
              name: "dashboard",
              href: paths.dashboard.root,
            },
            {
              name: "commandes",
              href: paths.dashboard.order.all_orders,
            },
            {
              name: "modifier une commande",
            },
          ]}
          sx={{
            mb: { xs: 3, md: 5 },
          }}
        />

        <Grid
          container
          justifyContent="flex-end"
          style={{ marginBottom: "16px" }}
        >
          <LoadingButton type="submit" variant="contained">
            Modifier la commande
          </LoadingButton>
        </Grid>
        <form onSubmit={handleSubmit(onSubmit)}>
          <Grid container spacing={3}>
            <Grid item xs={12} md={8}>
              <Card>
                <CardHeader title={`Details - N°`} />
                <Stack spacing={3} sx={{ p: 3 }}>
                  <TextField
                    name="creationDateTime"
                    label="Date de création"
                    type="datetime-local"
                    fullWidth
                    InputLabelProps={{
                      shrink: true,
                    }}
                  />
                  <Controller
                    name="etat"
                    control={control}
                    render={({ field }) => (
                      <Autocomplete
                        {...field}
                        id="combo-box-demo"
                        options={options}
                        disableClearable
                        fullWidth
                        renderInput={(params) => (
                          <TextField
                            {...params}
                            label="Etat"
                            error={!!errors.etat}
                            helperText={errors.etat?.message}
                          />
                        )}
                      />
                    )}
                  />
                  <Controller
                    name="client"
                    control={control}
                    render={({ field }) => (
                      <Autocomplete
                        {...field}
                        id="client-autocomplete"
                        options={clients}
                        fullWidth
                        renderInput={(params) => (
                          <TextField
                            {...params}
                            label="Client"
                            error={!!errors.client}
                            helperText={errors.client?.message}
                          />
                        )}
                      />
                    )}
                  />
                  <Grid container spacing={2} alignItems="center">
                    <Grid item xs={6}>
                      <Typography variant="h6" gutterBottom>
                        Facturation
                      </Typography>
                      <Typography variant="subtitle2" color="text.secondary">
                        Nom Complet:
                      </Typography>
                      <Typography variant="subtitle2" color="text.secondary">
                        Adresse:
                      </Typography>
                      <Typography variant="subtitle2" color="text.secondary">
                        Ville:
                      </Typography>
                      <Typography variant="subtitle2" color="text.secondary">
                        E-mail:
                      </Typography>
                      <Typography variant="subtitle2" color="text.secondary">
                        Téléphone:
                      </Typography>
                      <Typography variant="subtitle2" color="text.secondary">
                        Moyen de paiement:
                      </Typography>
                    </Grid>
                    <Grid item xs={6}>
                      <Typography variant="h6" gutterBottom>
                        Expédition
                      </Typography>
                      <Typography variant="subtitle2" color="text.secondary">
                        Nom Complet:
                      </Typography>
                      <Typography variant="subtitle2" color="text.secondary">
                        Adresse:
                      </Typography>
                      <Typography variant="subtitle2" color="text.secondary">
                        Code postal:
                      </Typography>
                      <Typography variant="subtitle2" color="text.secondary">
                        Ville:
                      </Typography>
                      <Typography variant="subtitle2" color="text.secondary">
                        Téléphone:
                      </Typography>
                      <Typography variant="subtitle2" color="text.secondary">
                        Note fournie par le client:
                      </Typography>
                    </Grid>
                  </Grid>
                </Stack>
              </Card>
            </Grid>
            <Grid item xs={12} md={4}>
              <Grid container>
                <Grid item xs={12} md={12}>
                  <Card sx={{ marginBottom: 2 }}>
                    <CardHeader title="Attribution de la commande" />
                    <Stack spacing={3} sx={{ p: 3 }}>
                      <Grid container spacing={2} alignItems="center">
                        <Grid item xs={6}>
                          <Typography variant="body2" gutterBottom>
                            Origine
                          </Typography>
                          <Typography
                            variant="subtitle2"
                            color="text.secondary"
                          >
                            site
                          </Typography>
                        </Grid>
                        <Grid item xs={6}>
                          <Typography variant="body2" gutterBottom>
                            Type d'appareil
                          </Typography>
                          <Typography
                            variant="subtitle2"
                            color="text.secondary"
                          >
                            tel
                          </Typography>
                        </Grid>
                      </Grid>
                    </Stack>
                  </Card>
                </Grid>
              </Grid>

              <Grid container>
                <Grid item xs={12} md={12}>
                  <Card>
                    <CardHeader title="Notes de commandes" />
                    <Stack spacing={3} sx={{ p: 3 }}>
                      <TextField
                        name="subDescription"
                        label="Ajouter une note"
                        multiline
                        rows={4}
                        fullWidth
                      />
                      <Grid container spacing={2} alignItems="center">
                        <Grid item xs={8}>
                          <Autocomplete
                            id="combo-box-demo"
                            options={note}
                            fullWidth
                            renderInput={(params) => (
                              <TextField {...params} label="Note" />
                            )}
                          />
                        </Grid>
                        <Grid item xs={4}>
                          <LoadingButton
                            type="submit"
                            variant="contained"
                            fullWidth
                            sx={{ height: 50 }}
                          >
                            Soumettre
                          </LoadingButton>
                        </Grid>
                      </Grid>
                    </Stack>
                  </Card>
                </Grid>
              </Grid>
            </Grid>

            <Grid item xs={12} md={8}>
              <Card>
                <Stack spacing={3} sx={{ p: 3 }}>
                  <TableContainer component={Paper}>
                    <Table sx={{ minWidth: 650 }} aria-label="simple table">
                      <TableHead>
                        <TableRow>
                          <TableCell>Article</TableCell>
                          <TableCell align="right">&nbsp;&nbsp;Coût</TableCell>
                          <TableCell align="right">Qte</TableCell>
                          <TableCell align="right">Total</TableCell>
                        </TableRow>
                      </TableHead>
                      <TableBody>
                        {orderItems.map((item, index) => (
                          <TableRow key={index}>
                            <TableCell>{item.Article}</TableCell>
                            <TableCell align="right">{item.Coût}€</TableCell>
                            <TableCell align="right">
                              {isRefundClicked ? (
                                <TextField
                                  type="number"
                                  value={item.Qte}
                                  onChange={(e) =>
                                    handleQuantityChange(index, e.target.value)
                                  }
                                />
                              ) : (
                                item.Qte
                              )}
                            </TableCell>
                            <TableCell align="right">{item.Total}€</TableCell>
                          </TableRow>
                        ))}
                      </TableBody>
                    </Table>
                  </TableContainer>

                  <Typography variant="subtitle2" align="right">
                    Sous-total des articles: 0,00€
                  </Typography>
                  <Typography variant="subtitle2" align="right">
                    Total de la commande : 0,00€
                  </Typography>
                  {isRefundClicked && !isCancelClicked && (
                    <Box>
                      <Grid
                        container
                        item
                        sx={{
                          display: "flex",
                          justifyContent: "flex-end",
                          flexDirection: "column",
                          flexGrow: 1,
                          alignItems: "flex-end",
                        }}
                      >
                        <Typography variant="subtitle2" align="right">
                          Montant déjà remboursé: -0,00€
                        </Typography>
                        <Grid item xs={12}>
                          <TextField
                            label="Montant du remboursement"
                            value={refundAmount}
                            onChange={(e) => setRefundAmount(e.target.value)}
                            fullWidth={true}
                            margin="normal"
                          />
                        </Grid>
                        <Grid item xs={12}>
                          <TextField
                            label="Motif du remboursement (facultatif)"
                            value={refundReason}
                            onChange={(e) => setRefundReason(e.target.value)}
                            fullWidth={true}
                            margin="normal"
                          />
                        </Grid>
                      </Grid>
                      <Grid
                        item
                        xs={12}
                        sx={{
                          display: "flex",
                          justifyContent: "space-between",
                        }}
                      >
                        <Button variant="contained" onClick={handleCancelClick}>
                          Annuler
                        </Button>

                        <Button variant="contained" onClick={handleRefund}>
                          Rembourser {refundAmount} € manuellement
                        </Button>
                      </Grid>
                    </Box>
                  )}
                  {isOrderCompleted && !isRefundClicked && (
                    <Grid
                      item
                      xs={12}
                      sx={{ display: "flex", justifyContent: "flex-end" }}
                    >
                      <LoadingButton
                        type="submit"
                        variant="contained"
                        onClick={handleRefundClick}
                      >
                        Remboursement
                      </LoadingButton>
                    </Grid>
                  )}
                </Stack>
              </Card>
            </Grid>

            <Grid item xs={12} md={4}>
              <Card sx={{ marginBottom: 2 }}>
                <CardHeader title="Facture/Envois" />
                <Stack spacing={3} sx={{ p: 3 }}>
                  <Grid container spacing={3}>
                    <Grid item xs={6} md={8}>
                      <Typography variant="subtitle2" gutterBottom>
                        Numéro de facture: 182395
                      </Typography>
                    </Grid>
                    <Grid item xs={6} md={8}>
                      <Typography variant="subtitle2" gutterBottom>
                        Facture
                      </Typography>
                    </Grid>
                    <Grid item xs={6} md={4}>
                      <Stack direction="row" spacing={1}>
                        <Tooltip title="Download">
                          <IconButton>
                            <Iconify icon="eva:cloud-download-fill" />
                          </IconButton>
                        </Tooltip>
                        <Tooltip title="Print">
                          <IconButton>
                            <Iconify icon="solar:printer-minimalistic-bold" />
                          </IconButton>
                        </Tooltip>
                      </Stack>
                    </Grid>
                  </Grid>
                  <Grid container spacing={3}>
                    <Grid item xs={6} md={8}>
                      <Typography variant="subtitle2" gutterBottom>
                        Bordereau d'expédition
                      </Typography>
                    </Grid>
                    <Grid item xs={6} md={4}>
                      <Stack direction="row" spacing={1}>
                        <Tooltip title="Download">
                          <IconButton>
                            <Iconify icon="eva:cloud-download-fill" />
                          </IconButton>
                        </Tooltip>
                        <Tooltip title="Print">
                          <IconButton>
                            <Iconify icon="solar:printer-minimalistic-bold" />
                          </IconButton>
                        </Tooltip>
                      </Stack>
                    </Grid>
                  </Grid>
                </Stack>
              </Card>
              <Card sx={{ marginBottom: 2 }}>
                <CardHeader title="Historique du client" />
                <Stack spacing={3} sx={{ p: 3 }}>
                  <Grid container spacing={3}>
                    <Grid item xs={6} md={8}>
                      <Typography variant="body2" gutterBottom>
                        Commandes totales
                      </Typography>
                      <Typography variant="subtitle2" color="text.secondary">
                        2
                      </Typography>
                    </Grid>
                    <Grid item xs={6} md={8}>
                      <Typography variant="body2" gutterBottom>
                        Revenu total
                      </Typography>
                      <Typography variant="subtitle2" color="text.secondary">
                        48,00€
                      </Typography>
                    </Grid>
                    <Grid item xs={6} md={8}>
                      <Typography variant="body2" gutterBottom>
                        Valeur moyenne des commandes
                      </Typography>
                      <Typography variant="subtitle2" color="text.secondary">
                        24,00€
                      </Typography>
                    </Grid>
                  </Grid>
                </Stack>
              </Card>
              <Card sx={{ marginBottom: 2 }}>
                <CardHeader title="Historique de modification" />
                <Stack spacing={3} sx={{ p: 3 }}>
                  <Grid item xs={12} md={12}>
                    <Alert icon={false} severity="info">
                      État de la commande modifié de En attente à Terminée.
                    </Alert>
                    <Typography variant="subtitle2" color="text.secondary">
                      04 avril 2024 à 11h36 par aya zouity
                    </Typography>
                  </Grid>
                  <Grid item xs={12} md={12}>
                    <Alert icon={false} severity="info">
                      Réduction des niveaux de stock : W115 – Jean fuchsia
                      (4993-24) (W115-fus-42)Couleur: Fuchsia, Taille UE: 42 1→0
                    </Alert>
                    <Typography variant="subtitle2" color="text.secondary">
                      04 avril 2024 à 11h36 par aya zouity
                    </Typography>
                  </Grid>
                </Stack>
              </Card>
            </Grid>
          </Grid>
        </form>
      </LocalizationProvider>
    </>
  );
}
