import React, { useState } from "react";
import {
  Card,
  Grid,
  Stack,
  TextField,
  IconButton,
  InputAdornment,
  Checkbox,
  FormControlLabel,
} from "@mui/material";
import Autocomplete from '@mui/material/Autocomplete';
import AddIcon from '@mui/icons-material/Add';
import DeleteIcon from '@mui/icons-material/Delete';
import LoadingButton from "@mui/lab/LoadingButton";

interface Entry {
    colonnes: string;
    operateur: string;
    valeur: string;
}

export default function FilterView() {
  const [entries, setEntries] = useState<Entry[]>([{ colonnes: "", operateur: "",valeur:"" }]);
  const [expedition, setExpedition] = useState<string>("");
  const [expeditionPrice, setExpeditionPrice] = useState<string>("");
  const [taxe, setTaxe] = useState<string>("");
  const [frais, setFrais] = useState<string>("");
  const [coupon, setCoupon] = useState<string>("");

  const handleAddEntry = () => {
    setEntries([...entries, { colonnes: "", operateur: "" ,valeur: "" }]);
  };

  const handleRemoveEntry = (index: number) => {
    const newEntries = [...entries];
    newEntries.splice(index, 1);
    setEntries(newEntries);
  };

  const handleInputChange = (index: number, field: keyof Entry, value: string) => {
    const newEntries = [...entries];
    newEntries[index][field] = value;
    setEntries(newEntries);
  };
  const handleSubmit = (event: React.FormEvent<HTMLFormElement>) => {
    event.preventDefault();
    console.log("Formulaire soumis !");
  };


  return (
    <form onSubmit={handleSubmit}>
     
        <Stack spacing={1} sx={{ p:5 }}>
          {entries.map((entry, index) => (
            <Grid container spacing={1} alignItems="center" key={index}>
              <Grid item xs={4} md={4}>
                <Autocomplete
                  value={entry.colonnes}
                  onChange={(event, newValue) =>
                    handleInputChange(index, "colonnes", newValue !== null ? newValue : "")
                  }
                  options={["commande", "client", "Article"]}
                  fullWidth
                  renderInput={(params) => <TextField {...params} label="Colonnes" />}
                />
              </Grid>
              <Grid item xs={4} md={4}>
                <Autocomplete
                  value={entry.operateur}
                  onChange={(event, newValue) =>
                    handleInputChange(index, "operateur", newValue !== null ? newValue : "")
                  }
                  options={["contient", "commence avec", "se termine par"]}
                  fullWidth
                  renderInput={(params) => <TextField {...params} label="Opérateur" />}
                />
              </Grid>
              <Grid item xs={3} md={2}>
                <TextField
                  value={entry.valeur}
                  onChange={(event) =>
                    handleInputChange(index, "valeur", event.target.value)
                  }
                  fullWidth
                  label="valeur"
                />
              </Grid>
              <Grid item xs={1} md={1} container justifyContent="flex-end">
                <IconButton onClick={handleAddEntry}>
                  <AddIcon fontSize="small" />
                </IconButton>
              </Grid>
              {index > 0 && (
                <Grid item xs={1} md={1} container >
                  <IconButton onClick={() => handleRemoveEntry(index)}>
                    <DeleteIcon fontSize="small" />
                  </IconButton>
                </Grid>
              )}
            </Grid>

          ))}
        </Stack>
        <LoadingButton type="submit" variant="contained" fullWidth>
       Filtrer les commandes
      </LoadingButton>
    
    </form>
  );
}