"use client"

import * as Yup from 'yup';
import { Controller, useForm } from 'react-hook-form';
import { yupResolver } from '@hookform/resolvers/yup';
import { ElementType, JSX, useMemo } from 'react';
import Chip, { ChipOwnProps } from '@mui/material/Chip';
import Grid from '@mui/material/Grid';
import Card from '@mui/material/Card';
import Stack from '@mui/material/Stack';
import CardHeader from '@mui/material/CardHeader';
import Typography from '@mui/material/Typography';

import { useResponsive } from '@/hooks/use-responsive';
import { useSnackbar } from '@/components/snackbar';
import FormProvider, {
    RHFTextField,
    RHFAutocomplete,
} from '@/components/hook-form';
import { _tags } from '@/shared/_mock';
import { TimePicker } from '@mui/x-date-pickers/TimePicker';
import { DatePicker } from '@mui/x-date-pickers/DatePicker';
import LoadingButton from '@mui/lab/LoadingButton';
import CustumImageCrop from '@/components/image-crop';
import CustomBreadcrumbs from '@/components/custom-breadcrumbs';
import { paths } from '@/routes/paths';
import { useSettingsContext } from '@/shared/components/settings';
import { Box, Container, Switch, TextField } from '@mui/material';
import { ILive, ILiveProduct } from '@/shared/types/live';
import { addLive } from '@/shared/api/live';
import label from '@/shared/components/label';
import Label from '@/shared/components/label';
import { RHFSwitch } from '@/shared/components/hook-form';



export default function PaypalConnexionView() {

    const mdUp = useResponsive('up', 'md');
    const paypalConnectionSchema = Yup.object().shape({
        sandbox: Yup.boolean().required(),
        connected: Yup.boolean().required(),
        liveEmail: Yup.string().email('Please enter a valid email').required('Email is required'),
        liveMerchantId: Yup.string().required('Merchant ID is required'),
        liveClientId: Yup.string().required('Client ID is required'),
        liveSecretKey: Yup.string().required('Secret Key is required'),
        sandboxEmail: Yup.string().email('Please enter a valid email'),
        sandboxMerchantId: Yup.string(),
        sandboxClientId: Yup.string(),
        sandboxSecretKey: Yup.string(),
      });
      
      const defaultValues = {
        sandbox: false,
        connected: true,
        liveEmail: "oussamaaftys@gmail.com", 
        liveMerchantId: "Z?DBEjdede-36HDJE3DBd36DHEdedjeddeded3DDEDed", 
        liveClientId: "DIHZEDZDZED-ez633hjdvede3gdehgd3gEGDEDJEDEGD-dedbede", 
        liveSecretKey: "Z?DBEjdede-36HDJE3DBd36DHEdedjeddeded3DDEDed", 
      };
      
    const methods = useForm({
        resolver: yupResolver(paypalConnectionSchema),
        defaultValues
    })

    const { handleSubmit, getValues, formState: { isSubmitting } } = methods;
    const { connected } = getValues();
    const onSubmit = handleSubmit((data) => {
        console.log(data)
    })

    const renderConnexionMode = (
        <>
            {mdUp && (
                <Grid md={4} paddingY={4}>
                    <Typography variant="h6" sx={{ mb: 0.5 }}>
                        Mode de connexion
                    </Typography>
                    <Typography variant="body2" sx={{ color: 'text.secondary' }}>
                        Connecter et choisir le mode de connexion paypal
                    </Typography>
                </Grid>
            )}
            <Grid xs={12} md={8} paddingY={2}>
                <Card >
                    {!mdUp && <CardHeader title="Mode de connexion" />}

                    <Stack spacing={3} sx={{ p: 3 }}>
                        <Grid container spacing={2} >
                            <Grid item xs={12} sm={6}>
                                <Card sx={{ p: 2, }} variant='outlined'>
                                    <Typography variant="subtitle1" gutterBottom>
                                        Status de Connexion
                                    </Typography>
                                    <Typography variant="body2" gutterBottom>
                                        Cliquez pour réinitialiser les identifiants actuels et utiliser un autre compte
                                    </Typography>
                                    <RHFSwitch name="connected" label={connected ? "connecté" : "déconnecté"} />
                                </Card>
                            </Grid>
                            <Grid item xs={12} sm={6}>
                                <Card sx={{ p: 2, }} variant='outlined'>
                                    <Typography variant="subtitle1" gutterBottom>
                                        Mode sandbox
                                    </Typography>
                                    <Typography variant="body2" gutterBottom>
                                        Activer le mode sandbox pour tester votre configuration paypal
                                    </Typography>
                                    <RHFSwitch name="sandbox" label={undefined} />
                                </Card>
                            </Grid>


                        </Grid>

                    </Stack>
                </Card>
            </Grid>
        </>
    );


    const renderLiveMode = (
        <>
            {mdUp && (
                <Grid md={4} paddingY={2}>
                    <Typography variant="h6" sx={{ mb: 0.5 }}>
                        le mode live
                    </Typography>
                    <Typography variant="body2" sx={{ color: 'text.secondary' }}>
                        definir les paramètres de connexion en mode live
                    </Typography>
                </Grid>
            )}
            <Grid xs={12} md={8} paddingY={2}>
                <Card >
                    {!mdUp && <CardHeader title="le mode live" />}

                    <Stack spacing={3} sx={{ p: 3 }}>
                        <Grid container spacing={2}>
                            <Grid item xs={12} md={6}>
                                <RHFTextField name="liveEmail" label="Adresse e-mail " />
                            </Grid>
                            <Grid item xs={12} md={6}>
                                <RHFTextField name="liveMerchantId" label="ID de marchand" />
                            </Grid>
                            <Grid item xs={12} md={6}>
                                <RHFTextField name="liveClientId" label="ID client" />
                            </Grid>
                            <Grid item xs={12} md={6}>
                                <RHFTextField  type="password" name="liveSecretkey" label="Clé secrète" />
                            </Grid>
                        </Grid>
                    </Stack>
                </Card>
            </Grid>
        </>
    );



    const renderSandboxMode = (
        <>
            {mdUp && (
                <Grid md={4} paddingY={2}>
                    <Typography variant="h6" sx={{ mb: 0.5 }}>
                        le mode sandbox
                    </Typography>
                    <Typography variant="body2" sx={{ color: 'text.secondary' }}>
                        definir les paramètres de connexion en mode sandbox
                    </Typography>
                </Grid>
            )}
            <Grid xs={12} md={8} paddingY={2}>
                <Card >
                    {!mdUp && <CardHeader title="le mode sandbox" />}

                    <Stack spacing={3} sx={{ p: 3 }}>
                        <Grid container spacing={2}>
                            <Grid item xs={12} md={6}>
                                <RHFTextField name="sandboxEmail" label="Adresse e-mail " />
                            </Grid>
                            <Grid item xs={12} md={6}>
                                <RHFTextField name="sandboxMerchantId" label="ID de marchand" />
                            </Grid>
                            <Grid item xs={12} md={6}>
                                <RHFTextField name="sandboxClientId" label="ID client" />
                            </Grid>
                            <Grid item xs={12} md={6}>
                                <RHFTextField  type="password" name="sandboxSecretkey" label="Clé secrète" />
                            </Grid>
                        </Grid>
                    </Stack>
                </Card>
            </Grid>
        </>
    );


    const renderActions = (
        <>
            {mdUp && <Grid md={4} />}
            <Grid xs={12} md={8} sx={{ display: 'flex', justifyContent: 'end', py: 2 }}>
                <LoadingButton
                    type="submit"
                    variant="contained"
                    size="large"
                    loading={isSubmitting}
                    sx={{ ml: 2 }}
                >Enregistrer</LoadingButton>

            </Grid>
        </>
    );

    

    return (
        
            <FormProvider methods={methods} onSubmit={onSubmit}>
                <Grid container spacing={3}>
                    {renderConnexionMode}
                    {renderLiveMode}
                    {renderSandboxMode}
                    {renderActions}
                </Grid>

            </FormProvider>

    );
}