import React, { useState, useCallback } from "react";
import Box from "@mui/material/Box";
import Card from "@mui/material/Card";
import Stack from "@mui/material/Stack";
import Divider from "@mui/material/Divider";
import Typography from "@mui/material/Typography";
import Button from "@mui/material/Button";
import InputAdornment from "@mui/material/InputAdornment";
import Grid from "@mui/material/Unstable_Grid2";
import {
  RHFUpload,
  RHFTextField,
  RHFSelect,
} from "@/shared/components/hook-form";

type VariationsProps = {
  handleDrop: (acceptedFiles: File[]) => void;
  handleRemoveFile: (inputFile: File | string) => void;
  handleRemoveAllFiles: () => void;
  values: any;
};

const Variations = ({
  handleDrop,
  handleRemoveFile,
  handleRemoveAllFiles,
  values,
}: VariationsProps) => {
  const [showManualForm, setShowManualForm] = useState(false);

  const toggleManualForm = () => {
    setShowManualForm(!showManualForm);
  };

  return (
    <>
      <Divider sx={{ borderStyle: "dashed" }} />
      <Typography variant="subtitle2">Ajout des variations</Typography>
      <Stack direction="row" alignItems="center" spacing={3}>
        <Button variant="outlined" onClick={toggleManualForm}>
          {showManualForm ? "Ajouter manuellement" : "Ajouter manuellement"}
        </Button>
        <Button variant="outlined">Ajouter massivement</Button>
      </Stack>
      {showManualForm && (
        <Grid xs={12} md={8}>
          <Card>
            <Stack spacing={3} sx={{ p: 3 }}>
              <Typography variant="subtitle2">Images</Typography>
              <RHFUpload
                multiple
                thumbnail
                name="images"
                maxSize={3145728}
                onDrop={handleDrop}
                onRemove={handleRemoveFile}
                onRemoveAll={handleRemoveAllFiles}
                onUpload={() => console.info("ON UPLOAD")}
              />
              <Box
                columnGap={2}
                rowGap={3}
                display="grid"
                gridTemplateColumns={{
                  xs: "repeat(1, 1fr)",
                  md: "repeat(2, 1fr)",
                }}
              >
                <RHFTextField
                  name="price"
                  label="Tarif régulier"
                  placeholder="0.00"
                  type="number"
                  InputLabelProps={{ shrink: true }}
                  InputProps={{
                    startAdornment: (
                      <InputAdornment position="start">
                        <Box component="span" sx={{ color: "text.disabled" }}>
                          €
                        </Box>
                      </InputAdornment>
                    ),
                  }}
                />
                <RHFTextField
                  name="priceSale"
                  label="Tarif promo"
                  placeholder="0.00"
                  type="number"
                  InputLabelProps={{ shrink: true }}
                  InputProps={{
                    startAdornment: (
                      <InputAdornment position="start">
                        <Box component="span" sx={{ color: "text.disabled" }}>
                          €
                        </Box>
                      </InputAdornment>
                    ),
                  }}
                />

                <RHFTextField
                  name="UGS"
                  label="UGS produit"
                  InputLabelProps={{ shrink: true }}
                  placeholder="UGS"
                />

                <RHFTextField
                  name="quantity"
                  label="Quantité"
                  placeholder="0"
                  type="number"
                  InputLabelProps={{ shrink: true }}
                />
              </Box>
              <RHFSelect
                native
                name="allowBackorder"
                label="Autoriser les commandes en réapprovisionnement ?"
                InputLabelProps={{ shrink: true }}
              >
                <option value="allow">Autoriser</option>
                <option value="allowWithNotification">
                  Autoriser, mais avec notification client
                </option>
                <option value="deny">Ne pas autoriser</option>
              </RHFSelect>
              <RHFTextField
                name="lowStockThreshold"
                label="Seuil de stock faible"
                type="number"
                InputLabelProps={{ shrink: true }}
                placeholder="0"
              />
              <Button variant="contained">Soumettre</Button>
            </Stack>
          </Card>
        </Grid>
      )}
    </>
  );
};

export default Variations;
