"use client";
import React, { useState } from 'react';
import Toolbar from '@mui/material/Toolbar';
import List from '@mui/material/List';
import ListItem from '@mui/material/ListItem';
import ListItemButton from '@mui/material/ListItemButton';
import ListItemText from '@mui/material/ListItemText';
import FormControl from '@mui/material/FormControl';
import TextField from '@mui/material/TextField';
import Button from '@mui/material/Button';
import { Checkbox } from '@mui/material';
import MenuItem from '@mui/material/MenuItem';
import CustomBreadcrumbs from '@/components/custom-breadcrumbs/custom-breadcrumbs';
import { paths } from '@/routes/paths';
import { Promocode, PromocodeType } from '@/contexts/types/promo';
import { useRouter } from 'next/navigation';
import { useSnackbar } from '@/components/snackbar';
import * as Yup from 'yup';
import { useForm } from 'react-hook-form';
import { useMemo } from 'react';
import { Category } from '@/contexts/types/promo';
import mockPromocodes from "@/shared/_mock/_promo";




type Props = {
  currentPromo?: Promocode;
  id?: string;
};



export default function Duplicatepromo({ id }: Props) {
  const [selectedSection, setSelectedSection] = useState<string>('General');
  const [code, setCode] = useState<string>('');
  const [typeCode, setTypeCode] = useState<PromocodeType>(PromocodeType.Remisepanier);
  const [valueCode, setValueCode] = useState<string>('');
  const [description, setDescription] = useState<string>('');
  const [expirationDate, setExpirationDate] = useState<Date>();

  const [category, setCategory] = useState<Category>(Category.tous);
  const [IDproduit, setIDproduit] = useState<string>('');
  const [Usage, setUsage] = useState<number>();
  const [Limit, setLimit] = useState<number>();
  const [startDate, setStartDate] = useState<Date>();
  const [IDproductexcluded, setIDproductexcluded] = useState<string>('');
  const [categoryexcluded, setCategoryexcluded] = useState<Category>(Category.tous);
  const [minAmount, setMinAmount] = useState<string>();


  const router = useRouter();
  const { enqueueSnackbar } = useSnackbar();
  const handleSectionClick = (section: string) => {
    setSelectedSection(section);
  };
  const CodePromoSchema = Yup.object().shape({

    code: Yup.string().required('Nom est requis'),
    typecode: Yup.string().required('Type de code est requis').oneOf(Object.values(PromocodeType), 'Type de code invalide'),
    Category: Yup.string().required('Category est requis').oneOf(Object.values(Category), 'Category invalide'),
    valuecode: Yup.string().required("Description est requis"),
    Description: Yup.string().required("Description est requis"),
    IDproduit: Yup.string().required("Description est requis"),
    Usage: Yup.number().required("Description est requis"),
    Limit: Yup.number().required("Description est requis"),
    expirationDate: Yup.date().required("Description est requis"),
    startDate: Yup.date().required("Description est requis"),
    IDproductexcluded: Yup.string().required("Description est requis"),
    categoryexcluded: Yup.string().required("Description est requis"),
    minAmount: Yup.string().required("Description est requis"),


  });

  const getPromoItem = mockPromocodes.find((promo) => promo.id === id);
  console.log('getPromoItem', getPromoItem)


  const defaultValues = useMemo(() => {
    setCode(getPromoItem?.code || '');
    setTypeCode(getPromoItem?.typecode || PromocodeType.Remisepanier);
    setValueCode(getPromoItem?.valuecode || '');
    setDescription(getPromoItem?.Description || '');
    setExpirationDate(getPromoItem?.expirationDate || new Date());
    setCategory(getPromoItem?.Category || Category.tous);
    setIDproduit(getPromoItem?.IDproduct || '');
    setUsage(getPromoItem?.Usage || 0);
    setLimit(getPromoItem?.Limit || 0);
    setStartDate(getPromoItem?.startDate || new Date());
    setIDproductexcluded(getPromoItem?.IDproductexcluded || '');
    setCategoryexcluded(getPromoItem?.categoryexcluded || Category.tous);
    setMinAmount(getPromoItem?.minAmount || '');

    return {
      code: getPromoItem?.code || '',
      typecode: getPromoItem?.typecode || PromocodeType.Remisepanier,
      valuecode: getPromoItem?.valuecode || 0,
      IDproduit: getPromoItem?.IDproduct || '',
      Usage: getPromoItem?.Usage || 0,
      Limit: getPromoItem?.Limit || 0,
      expirationDate: getPromoItem?.expirationDate || new Date(),
      Category: getPromoItem?.Category || Category.tous,
      Description: getPromoItem?.Description || '',
      startDate: getPromoItem?.startDate || new Date(),
      IDproductexcluded: getPromoItem?.IDproductexcluded || '',
      categoryexcluded: getPromoItem?.categoryexcluded || Category.tous,
      minAmount: getPromoItem?.minAmount || '',
    }
  }, [id]);
  const methods = useForm({

    defaultValues,
  });

  const {
    reset,
    watch,
    setValue,
    handleSubmit,
    formState: { isSubmitting },
  } = methods;

  const values = watch();



  const onSubmit = handleSubmit(async (data) => {
    try {
      await new Promise((resolve) => setTimeout(resolve, 500));
      reset();
      enqueueSnackbar('Create success!', { variant: 'success' });
      router.push(paths.promo.root);
      console.info('Form Data:', data);
    } catch (error) {
      console.error(error);
      enqueueSnackbar('Failed to create this new code promo.', { variant: 'error' });
    }
  });



  // Content for "General" section
  const generalContent = (
    <div>

      <form>
        <FormControl defaultValue="" required>
          <div className="main-content" style={{ marginLeft: '50px' }}>
            <p style={{ marginBottom: '30px' }}><b>General</b></p>
            <form>
              <FormControl defaultValue="" required>
                <TextField
                  id="outlined-nom-code"
                  label="nom du code promo"
                  type="search"
                  placeholder='entrer le nom du code promo'
                  variant="outlined"
                  value={code}
                  onChange={(e) => setCode(e.target.value)}
                  style={{ marginRight: '80px', marginBottom: '40px' }}
                />
                <TextField
                  id="outlined-description"
                  label="Description"
                  multiline
                  rows={4}
                  variant="outlined"
                  value={description}
                  onChange={(e) => setDescription(e.target.value)}
                  placeholder="Saisissez votre description ici..."
                  style={{ marginRight: '10px', marginBottom: '40px' }}
                />
                <TextField
                  id="outlined-type-code"
                  select
                  label="Type de promo"
                  value={values.typecode}


                  variant="outlined"
                  style={{ marginRight: '80px', marginBottom: '40px' }}
                >
                  {Object.values(PromocodeType).map((option) => (
                    <MenuItem key={option} value={option}>
                      {option}
                    </MenuItem>
                  ))}
                </TextField>
                <TextField
                  id="outlined-valeur-code"
                  label="valeur code promo"
                  type="search"
                  placeholder='0'
                  variant="outlined"
                  style={{ marginRight: '80px', marginBottom: '40px' }}
                  value={valueCode}
                  onChange={(e) => setValueCode(e.target.value)}
                />
                <div style={{ marginRight: '10px', marginBottom: '40px' }}>
                  <Checkbox defaultChecked size="small" />
                  <span>Cocher cette case si le code promo inclut l’expédition gratuite.</span>
                </div>
                <TextField
                  id="outlined-search-code"
                  label="date de debut du code promo"
                  type="date"
                  fullWidth
                  value={startDate}
                  InputLabelProps={{
                    shrink: true,
                  }}
                  placeholder='jj/mm/aaaa'
                  variant="outlined"
                  style={{ marginRight: '80px', marginBottom: '40px' }}

                />
                <TextField
                  id="outlined-search-code"
                  label="date de fin du code promo"
                  type="date"
                  fullWidth
                  InputLabelProps={{
                    shrink: true,
                  }}
                  placeholder='jj/mm/aaaa'
                  variant="outlined"
                  style={{ marginRight: '80px', marginBottom: '40px' }}
                  value={expirationDate}
                  onChange={(e) => setExpirationDate(new Date(e.target.value))}
                />
              </FormControl>
            </form>
          </div>
          {/* Your input fields for General section */}
        </FormControl>
      </form>
    </div>
  );


  const usageRestrictionContent = (
    <div>
      <FormControl defaultValue="" required>
        <div className="main-content">
          <p style={{ marginBottom: '30px' }}><b>Restriction d'usage</b></p>
          <form>
            <div style={{ marginBottom: '40px' }}>
              <TextField
                id="outlined-usage-restriction"
                label="Dépense minimale"
                variant="outlined"
                value={minAmount}
                placeholder="Aucun montant minimum"
                style={{ marginRight: '10px', width: '300px' }}
              />
            </div>
            <div style={{ marginBottom: '40px' }}>
              <div style={{ marginBottom: '40px', display: 'flex', alignItems: 'center' }}>
                <Checkbox defaultChecked size="small" />
                <span style={{ marginLeft: '10px', maxWidth: '360px', display: 'inline-block' }}>Cochez cette case si le code promo ne peut être utilisé conjointement avec d’autres codes promo.</span>
              </div>
            </div>
            <div style={{ marginBottom: '40px' }}>
              <TextField
                id="outlined-produit-restriction"
                label="Réduction par produit"
                variant="outlined"
                placeholder="ID produit"
                value={IDproduit}
                style={{ marginRight: '10px', width: '300px' }}
              />
            </div>
            <div style={{ marginBottom: '40px' }}>
              <TextField
                id="outlined-prod-restriction"
                label="Exclure un produit"
                variant="outlined"
                placeholder="ID produit"
                value={IDproductexcluded}
                style={{ marginRight: '10px', width: '300px' }}
              />
            </div>
            <div style={{ marginBottom: '40px' }}>
              <TextField
                id="outlined-category-restriction"
                label="Réduction par catégorie"
                variant="outlined"
                placeholder="catégorie"
                value={category}
                style={{ marginRight: '10px', width: '300px' }}
              />
            </div>
            <div style={{ marginBottom: '40px' }}>
              <TextField
                id="outlined-categ-restriction"
                label="Exclure une catégorie"
                variant="outlined"
                placeholder="catégorie"
                value={categoryexcluded}
                style={{ marginRight: '10px', width: '300px' }}
              />
            </div>

          </form>
        </div>
      </FormControl>
    </div>
  );
  const LimitUtilisationContent = (
    <div>
      <FormControl defaultValue="" required>
        <div className="main-content">
          <p style={{ marginBottom: '30px' }}><b>limite d'utilisation</b></p>

          <div style={{ marginBottom: '40px' }}>
            <TextField
              id="outlined-limit-code"
              label="Limite d’utilisation par code promo"
              variant="outlined"
              value={Limit}
              placeholder="Utilisation illimitée"
              style={{ marginRight: '10px', width: '300px' }}
            />
          </div>


          <div style={{ marginBottom: '40px' }}>
            <TextField
              id="outlined-limit-code"
              label="Limite d’utilisation par utilisateur"
              variant="outlined"
              value={Usage}
              placeholder="Utilisation illimitée"
              style={{ marginRight: '10px', width: '300px' }}
            />
          </div>



        </div>
      </FormControl>
    </div>
  );

  return (
    <div style={{ display: 'flex' }}>

      <div style={{ width: '200px', marginRight: '80px' }}>
        <Toolbar />
        <p style={{ marginBottom: '0' }}><b>Dupliquer un promo code</b></p>
        <List style={{ marginTop: '0' }}>
          {['General', 'restriction d\'usage', 'Limite d\'utilisation'].map((text, index) => (
            <ListItem key={text} disablePadding onClick={() => handleSectionClick(text)}>
              <ListItemButton selected={selectedSection === text}>
                <ListItemText primary={text} />
              </ListItemButton>
            </ListItem>
          ))}
        </List>
      </div>
      {/* Main content */}
      <div className="main-content" style={{ marginLeft: '50px' }}>
        <CustomBreadcrumbs

          links={[
            {
              name: 'dashboard',
              href: paths.dashboard.root,
            },

            {
              name: 'liste des codes promo',
              href: paths.promo.all_promo,
            },

            {
              name: 'Ajouter un codes promo',
            },
          ]}
          sx={{
            mb: { xs: 3, md: 5 },
          }}
        />
        <Button variant="contained" color="primary" style={{ marginLeft: '300px', marginBottom: '40px' }}>Enregistrer les modifications</Button>

        {selectedSection === 'General' && generalContent}
        {selectedSection === 'restriction d\'usage' && usageRestrictionContent}
        {selectedSection === 'Limite d\'utilisation' && LimitUtilisationContent}
      </div>
    </div>
  );
}
