'use client';

import { useCallback } from 'react';
import Table from '@mui/material/Table';
import Button from '@mui/material/Button';
import Tooltip from '@mui/material/Tooltip';
import Container from '@mui/material/Container';
import TableBody from '@mui/material/TableBody';
import TableCell from '@mui/material/TableCell';
import Grid from '@mui/material/Grid';
import TableHead from '@mui/material/TableHead';
import IconButton from '@mui/material/IconButton';
import { useTheme } from '@mui/material/styles';
import TableContainer from '@mui/material/TableContainer';
import LocalizationProvider from '@/shared/locales/localization-provider';
import { useBoolean } from '@/hooks';
import { shippingAreaList } from '@/shared/_mock/_shipping';
import Iconify from '@/shared/components/iconify';
import Scrollbar from '@/shared/components/scrollbar';
import { useSettingsContext } from '@/shared/components/settings';
import CustomBreadcrumbs from '@/components/custom-breadcrumbs';
import { useTable, emptyRows, TableNoData, TableSelectedAction, TablePaginationCustom, TableEmptyRows, } from '@/shared/components/table';
import ShippingAreaTableRow from './ShippingAreaTableRow';
import { Reorder } from 'framer-motion';
import { Autocomplete, Box, InputAdornment, Modal, TextField, Typography } from '@mui/material';
import { useEffect, useState } from 'react';
import * as Yup from 'yup';
import { Controller, useForm } from 'react-hook-form';
import { yupResolver } from '@hookform/resolvers/yup';
import { useMemo } from 'react';
import Chip from '@mui/material/Chip';
import Card from '@mui/material/Card';
import Stack from '@mui/material/Stack';
import { useSnackbar } from '@/components/snackbar';
import FormProvider, {
  RHFAutocomplete,
} from '@/components/hook-form';
import { paths } from '@/routes/paths';
import { IShippingAreaItem, ShippingMethod } from '@/contexts/types/Shipping';
import { shippingMethodsList } from '@/shared/_mock/_shipping'
import { countries } from '@/shared/assets/data/countries'
import { useRouter } from '@/hooks';
import { useAddShippingArea, useDeleteShippingArea, useGetAllShippingArea, useGetShippingArea, useGetShippingMethod, useGetShippingMethods, useUpdateShippingArea } from '@/shared/api/shipping';


export default function ShippingAreaTableView() {
  const { enqueueSnackbar } = useSnackbar();

  const theme = useTheme();

  const settings = useSettingsContext();
  const router = useRouter();
  const table = useTable({ defaultOrderBy: 'name' });
  const confirm = useBoolean();
  const { shippingAreaData } = useGetAllShippingArea();
  const [tableData, setTableData] = useState<IShippingAreaItem[]>(shippingAreaData);

  const { shippingMethodData } = useGetShippingMethods();
  const [shippingMethodList, setShippingMethodList] = useState<ShippingMethod[]>(shippingMethodData);

  const countryLabels = countries.map(country => country.label);

  const dataInPage = tableData.slice(
    table.page * table.rowsPerPage,
    table.page * table.rowsPerPage + table.rowsPerPage
  );

  const denseHeight = table.dense ? 56 : 56 + 20;


  const notFound = (!tableData.length) || !tableData.length;

  //----------------------------------------------------------------------------------  

  const [openAddModal, setOpenAddModal] = useState(false);
  const [openEditModal, setOpenEditModal] = useState(false);


  const handleAddClick = () => {
    methods.reset({ regionList: [] });
    reset();
    setOpenAddModal(true);
  };

  const handleEditClick = (id: string) => {
    const shippingAreaEdited: IShippingAreaItem | undefined = tableData.find((a) => a.id === id);
    if (shippingAreaEdited) {
      setShippingAreaEditing(shippingAreaEdited);
    }
    methods.reset(defaultValues);
    setOpenEditModal(true);
  };

  const [shippingAreaEditing, setShippingAreaEditing] = useState<IShippingAreaItem>();

  const NewShippingAreaSchema = Yup.object().shape({
    name: Yup.string().required('Nom est requis'),
    regionList: Yup.array().required('Région est requis'),
    shippingMethodList: Yup.array().required("Méthode de livraison est requis")
  });

  const defaultValues = useMemo(() => ({
    name: shippingAreaEditing?.name || '',
    regionList: shippingAreaEditing?.regionList || [],
    shippingMethodList: shippingAreaEditing?.shippingMethodList || []
  }), [shippingAreaEditing]);

  const methods = useForm({
    resolver: yupResolver(NewShippingAreaSchema),
    defaultValues,
  });

  const {
    reset,
    handleSubmit,
    formState: { isSubmitting },
    control
  } = methods;

  useEffect(() => {
    if (shippingAreaEditing) {
      reset(defaultValues);
    }
    console.log(defaultValues);
  }, [shippingAreaEditing, defaultValues, reset])

  useEffect(() => {
    setTableData(shippingAreaData);
  }, [shippingAreaData])

  const handleCloseEditModal = () => {
    setOpenEditModal(false);
    setSelectedShippingArea(null);
    reset();
  };

  const handleCloseAddModal = () => {
    setOpenAddModal(false);
    reset();
  };

  const handleAddForm = () => {
    setOpenAddModal(false);
  };

  const handleEditForm = () => {
    setOpenEditModal(false);
  };

  //----------------view details--------------

  const [selectedShippingArea, setSelectedShippingArea] = useState<IShippingAreaItem | null>(null);
  const handelSelectedShippingArea = (shippingArea: any) => {
    setSelectedShippingArea(shippingArea);
  };
  const handleViewRow = useCallback(
    (id: string) => {
      const shippingArea = tableData.find((a) => a.id === id);
      handelSelectedShippingArea(shippingArea)
    },
    [tableData]
  );

  //----------------Change ordre of row---------------
  const handleReorder = (newOrder: number[]) => {
    const reorderedData = newOrder.map(index => tableData[index]);
    setTableData(reorderedData);
  };

  //-----------tab-------------------
  const [value, setValue] = useState('1');

  const handleChange = (event: React.SyntheticEvent, newValue: string) => {
    setValue(newValue);
  };

  /////////////////////////////CRUD Method///////////////////////////
  const handleAddFormSubmit = (formData: any) => {
    console.log("ship method view : " + formData.shippingMethodList)

    useAddShippingArea(formData)
      .then(() => {
        enqueueSnackbar("ShippingArea created successfully", { variant: "success" });
        reset();
        setOpenAddModal(false);
      })
      .catch((error) => {
        enqueueSnackbar(error, { variant: 'error' });
        console.log(error)
      })
  };

  const handleEditFormSubmit = (data: any) => {
    if (shippingAreaEditing) {
      const formDataEdit = {
        id: shippingAreaEditing.id,
        ...data,
      };
      useUpdateShippingArea(shippingAreaEditing?.id, formDataEdit).then(() => {
        enqueueSnackbar('ShippingArea updated successfully', { variant: 'success' });
        setOpenEditModal(false);
        reset();
      }).catch((error) => {
        enqueueSnackbar(error, { variant: 'error' });
        console.error(error);
      })
    }
  };

  const handleDeleteRow = useCallback(
    async (id: string) => {
      try {
        await useDeleteShippingArea(id);
        const updatedTableData = tableData.filter((row) => row.id !== id);
        setTableData(updatedTableData);
        table.onUpdatePageDeleteRow(updatedTableData.length);
        enqueueSnackbar('Zone d\'expédition supprimée avec succès', { variant: 'success' });
      } catch (error) {
        console.error(`Error deleting shipping area with ID ${id}:`, error);
        enqueueSnackbar('Erreur lors de la suppression de la zone d\'expédition', { variant: 'error' });
      }
    },
    [tableData, table, enqueueSnackbar]
  );

  return (
    <>
      <LocalizationProvider >
        <Container maxWidth={settings.themeStretch ? false : 'lg'}>
          <Grid container alignItems="center" justifyContent="space-between">
            <Grid item>
              <CustomBreadcrumbs
                heading="Zones d'expédition"
                links={[
                  {
                    name: 'Dashboard',
                    href: paths.dashboard.root,
                  },
                  {
                    name: "Livraison",
                  }
                ]}
                sx={{
                  mb: { xs: 3, md: 5 },
                }}
              />
            </Grid>
            <Grid item>
              <Stack
                spacing={3}
                justifyContent="space-between"
                alignItems={{ xs: 'flex-end', sm: 'center' }}
                direction={{ xs: 'column', sm: 'row' }}
              >
                <Button
                  variant="contained"
                  color='success'
                  startIcon={<Iconify icon="mingcute:add-line" />}
                  onClick={handleAddClick}
                >
                  Ajouter
                </Button>
              </Stack>
            </Grid>
          </Grid>

          <Card>
            <TableContainer sx={{ position: 'relative', overflow: 'unset' }}>
              <TableSelectedAction
                dense={table.dense}
                numSelected={table.selected.length}
                rowCount={tableData.length}
                onSelectAllRows={(checked) => {
                  table.onSelectAllRows(
                    checked,
                    tableData.map((row) => row.id)
                  );
                }}
                action={
                  <Stack direction="row">
                    <Tooltip title="Archive">
                      <IconButton color="primary" onClick={confirm.onTrue}>
                        <Iconify icon="clarity:archive-solid" />

                      </IconButton>
                    </Tooltip>

                    <Tooltip title="Delete">
                      <IconButton color="primary" onClick={confirm.onTrue}>
                        <Iconify icon="solar:trash-bin-trash-bold" />
                      </IconButton>
                    </Tooltip>
                  </Stack>
                }
              />
              <TableHead sx={{ width: '100%' }} >
                <TableCell width={'30%'}>Nom</TableCell>
                <TableCell width={'30%'}>Régions</TableCell>
                <TableCell width={'33%'}>Méthodes de livraison</TableCell>
                <TableCell width={'7%'}>Actions</TableCell>
              </TableHead>

              <Scrollbar>
                <Table size={table.dense ? 'small' : 'medium'} sx={{ minWidth: 800 }}>
                  <TableBody>
                    <Reorder.Group
                      axis="y" // Vertical reordering
                      values={tableData.map((_, index) => index)} // Array of indices representing the current order
                      onReorder={handleReorder} // Callback function to handle reordering
                    >
                      {tableData
                        .slice(
                          table.page * table.rowsPerPage,
                          table.page * table.rowsPerPage + table.rowsPerPage
                        )
                        .map((row, index) => (
                          <Reorder.Item key={row.id} value={index}> {/* Use index as value for Reorder.Item */}
                            <ShippingAreaTableRow
                              key={row.id}
                              row={row}
                              selected={table.selected.includes(row.id)}
                              onSelectRow={() => table.onSelectRow(row.id)}
                              onViewRow={() => handleViewRow(row.id)}
                              selectedShippingArea={selectedShippingArea}
                              onEditRow={() => handleEditClick(row.id)}
                              onDeleteRow={() => handleDeleteRow(row.id)}
                            />
                          </Reorder.Item>
                        ))}
                    </Reorder.Group>
                    <TableEmptyRows
                      height={denseHeight}
                      emptyRows={emptyRows(table.page, table.rowsPerPage, tableData.length)}
                    />
                    <TableNoData notFound={notFound} />
                  </TableBody>
                </Table>
              </Scrollbar>
            </TableContainer>

            <TablePaginationCustom
              count={tableData.length}
              page={table.page}
              rowsPerPage={table.rowsPerPage}
              onPageChange={table.onChangePage}
              onRowsPerPageChange={table.onChangeRowsPerPage}
              dense={table.dense}
              onChangeDense={table.onChangeDense}
            />
          </Card>
        </Container>
      </LocalizationProvider>

      <Modal open={openAddModal} onClose={handleCloseAddModal}>
        <FormProvider methods={methods} onSubmit={handleSubmit(handleAddFormSubmit)}>
          <Box sx={{ position: 'absolute', top: '50%', left: '50%', transform: 'translate(-50%, -50%)', width: 500, bgcolor: 'background.paper', boxShadow: 24, p: 4, borderRadius: 3 }}>
            <Typography variant="h6" align="center" gutterBottom sx={{ mt: 2, mb: 3 }}>Ajouter une zone d'expédition</Typography>
            <Controller
              name='name'
              control={control}
              render={({ field }) => (
                <TextField
                  {...field}
                  label="Nom de la zone"
                  type="text"
                  sx={{ m: 1, width: '97%' }}
                />
              )}
            />
            <Controller
              name="regionList"
              control={control}
              defaultValue={[]}
              render={({ field }) => (
                <RHFAutocomplete
                  {...field}
                  sx={{ ml: 1, mr: 1, width: '97%' }}
                  label="Régions"
                  placeholder="+ Régions"
                  multiple
                  freeSolo
                  options={countryLabels}
                  disableCloseOnSelect
                  getOptionLabel={(option) => option}
                  renderOption={(props, option) => (
                    <li {...props} key={option}>
                      {option}
                    </li>
                  )}
                  renderTags={(selected, getTagProps) =>
                    selected.map((option, index) => (
                      <Chip
                        {...getTagProps({ index })}
                        key={option}
                        label={option}
                        size="small"
                        color="success"
                        variant="soft"
                      />
                    ))
                  }
                  onChange={(event, newValue) => field.onChange(newValue)}
                />
              )}
            />
            <Controller
              name="shippingMethodList"
              control={control}
              defaultValue={[]}
              render={({ field }) => (
                <Autocomplete
                  multiple
                  disableCloseOnSelect
                  options={shippingMethodData}
                  sx={{ ml: 1, mr: 1, mt: 1, width: '97%' }}
                  getOptionLabel={(option) => option.name}
                  value={field.value}
                  onChange={(_, value) => {
                    field.onChange(value);
                  }}
                  isOptionEqualToValue={(option, value) => option.id === value.id}
                  renderInput={(params) => (
                    <TextField
                      {...params}
                      label="Méthodes de livraison"
                      placeholder="+ Méthodes de livraison"
                    />
                  )}
                  renderTags={(selected, getTagProps) =>
                    selected.map((option, index) => (
                      <Chip
                        {...getTagProps({ index })}
                        key={option.id}
                        label={option.name}
                        size="small"
                        color="success"
                        variant="soft"
                      />
                    ))
                  }
                />
              )}
            />
            <Box sx={{ display: 'flex', justifyContent: 'center', mt: 3 }}>
              <Button onClick={() => setOpenAddModal(false)} sx={{ mt: 2, mb: 2, mr: 1 }} variant="outlined" color="inherit">Annuler</Button>
              <Button type="submit" sx={{ mt: 2, mb: 2 }} variant="contained" color="inherit">Ajouter</Button>
            </Box>
          </Box>
        </FormProvider>
      </Modal>

      <Modal open={openEditModal} onClose={handleCloseEditModal}>
        <FormProvider methods={methods} onSubmit={handleSubmit(handleEditFormSubmit)}>
          <Box sx={{ position: 'absolute', top: '50%', left: '50%', transform: 'translate(-50%, -50%)', width: 500, bgcolor: 'background.paper', boxShadow: 24, p: 4, borderRadius: 3 }}>
            <Typography variant="h6" align="center" gutterBottom sx={{ mt: 2, mb: 3 }}>Modifier une zone d'expédition</Typography>
            <Controller
              name='name'
              control={control}
              render={({ field }) => (
                <TextField
                  {...field}
                  label="Nom de la zone"
                  type="text"
                  defaultValue={shippingAreaEditing?.name}
                  sx={{ m: 1, width: '97%' }}
                />
              )}
            />
            <Controller
              name="regionList"
              control={control}
              defaultValue={[]}
              render={({ field }) => (
                <RHFAutocomplete
                  {...field}
                  sx={{ ml: 1, mr: 1, width: '97%' }}
                  label="Régions"
                  placeholder="+ Régions"
                  multiple
                  freeSolo
                  options={countryLabels}
                  disableCloseOnSelect
                  getOptionLabel={(option) => option}
                  renderOption={(props, option) => (
                    <li {...props} key={option}>
                      {option}
                    </li>
                  )}
                  renderTags={(selected, getTagProps) =>
                    selected.map((option, index) => (
                      <Chip
                        {...getTagProps({ index })}
                        key={option}
                        label={option}
                        size="small"
                        color="success"
                        variant="soft"
                      />
                    ))
                  }
                  onChange={(event, newValue) => field.onChange(newValue)}
                />
              )}
            />
            <Controller
              name="shippingMethodList"
              control={control}
              defaultValue={[]}
              render={({ field }) => (
                <Autocomplete
                  multiple
                  disableCloseOnSelect
                  options={shippingMethodData}
                  sx={{ ml: 1, mr: 1, mt: 1, width: '97%' }}
                  getOptionLabel={(option) => option.name}
                  value={field.value}
                  onChange={(_, value) => {
                    field.onChange(value);
                  }}
                  isOptionEqualToValue={(option, value) => option.id === value.id}
                  renderInput={(params) => (
                    <TextField
                      {...params}
                      label="Méthodes de livraison"
                      placeholder="+ Méthodes de livraison"
                    />
                  )}
                  renderTags={(selected, getTagProps) =>
                    selected.map((option, index) => (
                      <Chip
                        {...getTagProps({ index })}
                        key={option.id}
                        label={option.name}
                        size="small"
                        color="success"
                        variant="soft"
                      />
                    ))
                  }
                />
              )}
            />
            <Box sx={{ display: 'flex', justifyContent: 'center', mt: 3 }}>
              <Button onClick={() => setOpenEditModal(false)} sx={{ mt: 2, mb: 2, mr: 1 }} variant="outlined" color="inherit">Annuler</Button>
              <Button type="submit" sx={{ mt: 2, mb: 2 }} variant="contained" color="inherit">Modifier</Button>
            </Box>
          </Box>
        </FormProvider>
      </Modal>
    </>
  );
}
