import { useState } from 'react';
import Grid from '@mui/material/Unstable_Grid2';
import { DatePicker } from '@mui/x-date-pickers/DatePicker';
import StatisticsDeliveredOrders from './StatisticsDeliveredOrders';
import CustomBreadcrumbs from '@/components/custom-breadcrumbs/custom-breadcrumbs';
import { paths } from '@/routes/paths';


// ----------------------------------------------------------------------

export default function ShippingStatisticsView() {

    let commandes: { codepostal: string; dateLivraison: Date }[] = [];

    const codesPostaux = generateCodesPostaux(30);
    codesPostaux.forEach(codepostal => {
        let nombreCommandes = generateRandomNumber(10, 100);
        for (let i = 0; i < nombreCommandes; i++) {
            let dateLivraison = generateRandomDate();
            commandes.push({ codepostal, dateLivraison });
        }
    });

    function generateCodesPostaux(minimum: number): string[] {
        let codesPostaux: string[] = [];
        while (codesPostaux.length < 25) {
            let codepostal = generateRandomCodePostal();
            if (!codesPostaux.includes(codepostal)) {
                codesPostaux.push(codepostal);
            }
        }
        return codesPostaux;
    }

    function generateRandomCodePostal(): string {
        const min = 10;
        const max = 99;
        const codepostal = Math.floor(Math.random() * (max - min + 1) + min).toString();
        return codepostal;
    }

    function generateRandomDate(): Date {
        let year = 2024;
        let month = Math.floor(Math.random() * 12) + 1;
        let day = Math.floor(Math.random() * 28) + 1;
        return new Date(year, month - 1, day);
    }

    function generateRandomNumber(min: number, max: number): number {
        return Math.floor(Math.random() * (max - min + 1)) + min;
    }

    console.log(commandes);

    const [data, setData] = useState(commandes);
    const [selectedDate, setSelectedDate] = useState<Date | null>(null);

    const handleDateChange = (date: Date | null) => {
        setSelectedDate(date);
        const filteredData = commandes.filter(commande =>
            selectedDate ? new Date(commande.dateLivraison).toDateString() === new Date(selectedDate).toDateString() : true
        );
        setData(filteredData);
    };

    let commandesParCodePostal: { label: string; value: number }[] = [];

    let countMap: { [codePostal: string]: number } = {};
    data.forEach(data => {
        if (countMap[data.codepostal]) {
            countMap[data.codepostal]++;
        } else {
            countMap[data.codepostal] = 1;
        }
    });

    for (let codepostal in countMap) {
        commandesParCodePostal.push({ label: codepostal, value: countMap[codepostal] });
    }

    console.log(commandesParCodePostal);




    return (
        <>
            <Grid xs={12} md={12} container>
                <Grid xs={12} md={4}>
                    <CustomBreadcrumbs
                        heading="Statistiques de livraison"
                        links={[
                            {
                                name: 'Dashboard',
                                href: paths.dashboard.root,
                            },
                            {
                                name: "Livraison",
                            }
                        ]}
                        sx={{
                            mb: { xs: 3, md: 5 },
                        }}
                    />
                </Grid>
                <Grid xs={12} md={8} mt={5}>
                    <DatePicker
                        label="Date de livraison"
                        slotProps={{
                            textField: {
                                fullWidth: true,
                            },
                        }}
                        sx={{
                            maxWidth: { md: 200 },
                        }}
                        value={selectedDate}
                        onChange={handleDateChange}
                    />
                    <StatisticsDeliveredOrders
                        title="Commandes livrer par code postal"
                        chart={{
                            series: commandesParCodePostal
                        }}
                        sx={{ mt: 2 }}
                    />
                </Grid>
            </Grid>
        </>
    );
}
