'use client'

import { useState, useEffect, useMemo } from 'react';
import * as Yup from 'yup';
import { useForm } from 'react-hook-form';
import { yupResolver } from '@hookform/resolvers/yup';
import Grid from '@mui/material/Unstable_Grid2';
import Card from '@mui/material/Card';
import Divider from '@mui/material/Divider';
import Button from '@mui/material/Button';
import Chip from '@mui/material/Chip';
import Stack from '@mui/material/Stack';
import Typography from '@mui/material/Typography';
import { useSnackbar } from '@/components/snackbar';
import LoadingButton from '@mui/lab/LoadingButton';
import FormLabel from '@mui/material/FormLabel';
import Checkbox from '@mui/material/Checkbox';
import FormProvider, {
    RHFEditor,
    RHFTextField,
    RHFAutocomplete,
} from "@/shared/components/hook-form";
import Box from '@mui/material/Box';
import Modal from '@mui/material/Modal';
import { EmailConfig } from '@/contexts/types/Shipping';
import AddMediaButton from '@/shared/sections/media/view/Add-media-button';
import { useResponsive } from '@/hooks/use-responsive';


const SmartTags_OPTIONS = [
    { value: "Blog_Info", label: "Blog Info" },
    { value: "Home_Url", label: "Home URL" },
];

const RegisterFormType_OPTIONS = [
    { value: "Default_Form", label: "Default Form" },
    { value: "Untitled", label: "Untitled" },
];

const style = {
    position: 'absolute' as 'absolute',
    top: '50%',
    left: '50%',
    transform: 'translate(-50%, -50%)',
    width: 400,
    bgcolor: 'background.paper',
    border: '2px solid #FFF',
    boxShadow: 24,
    p: 4,
};



export default function ConfigEmailView() {

    const { enqueueSnackbar } = useSnackbar();
    const mdUp = useResponsive('up', 'md');

    const ConfigEmailSchema = Yup.object().shape({
        subject: Yup.string(),
        description: Yup.string(),
    });


    const defaultSubject = "Votre commande n°[expedition] a été expédiée.";
    const defaultDescription = "Bonjour [prenom] [nom], \n Nous vous informons que votre commande a été expédiée. \nVous la recevrez sous peu, mais si vous souhaitez garder un œil dessus, vous pouvez vous rendre sur [lien] pour suivre son trajet. \nL'expédition [expedition] sera livrée à l’adresse suivante : [adresse]. \nN'hésitez pas à nous contacter pour toute information complémentaire. \nVotre service client";

    const emailConfigValue: EmailConfig = {
        subject: defaultSubject,
        description: defaultDescription
    };

    const defaultValues = useMemo(() => ({
        subject: emailConfigValue.subject,
        description: emailConfigValue.description,
    }), []);

    const methods = useForm({
        resolver: yupResolver(ConfigEmailSchema),
    });

    const {
        reset,
        handleSubmit,
        formState: { isSubmitting },
    } = methods;

    useEffect(() => {
        reset(defaultValues);
        console.log(defaultValues)
    }, [defaultValues, reset])

    const onSubmit = handleSubmit(async (data) => {
        try {
            await new Promise((resolve) => setTimeout(resolve, 500));
            enqueueSnackbar('Success config!', { variant: 'success' });
            console.info('Form Data:', data);
        } catch (error) {
            console.error(error);
            enqueueSnackbar('Failed config.', { variant: 'error' });
        }
    });

    const [checked, setChecked] = useState(true);

    const handleChange = (event: React.ChangeEvent<HTMLInputElement>) => {
        setChecked(event.target.checked);
    };

    const [open, setOpen] = useState(false);
    const handleOpen = () => setOpen(true);
    const handleClose = () => setOpen(false);

    const renderBasic = (
        <>
            <Grid xs={12} md={12}>

                <Stack spacing={3}>

                    <Typography variant="h6" sx={{ mb: 0.5 }}>
                        Configuration des emails
                    </Typography>
                    <Grid container alignItems="center" spacing={1} mt={1}>
                        <Grid>
                            <Checkbox
                                name='sendEmailToCustomerWhenCreatingExpedition'
                                checked={checked}
                                onChange={handleChange}
                                color='success'
                                inputProps={{ 'aria-label': 'primary checkbox' }}
                            />
                        </Grid>
                        <Grid>
                            <Typography>Envoyer un email au client lors de la création d'une expédition</Typography>
                        </Grid>
                    </Grid>
                    <Typography component="div">
                        <Typography sx={{ mb: 0.5 }} fontSize={14} mt={3}>
                            <strong style={{ fontWeight: 'bold' }}>Shortcodes :</strong>
                        </Typography>
                        <Typography fontSize={13}>
                            <span>[lien] :</span> affichage du lien de suivi du colis <span style={{ fontStyle: 'italic' }}>(obligatoire)</span>
                        </Typography>
                        <Typography fontSize={13}>
                            <span>[expedition] :</span> numéro d'expédition <span style={{ fontStyle: 'italic' }}>(obligatoire)</span>
                        </Typography>
                        <Typography fontSize={13}>
                            <span>[prenom] :</span> Prénom du client
                        </Typography>
                        <Typography fontSize={13}>
                            <span>[nom] :</span> Nom du client
                        </Typography>
                        <Typography fontSize={13}>
                            <span>[adresse] :</span> Adresse de livraison
                        </Typography>
                    </Typography>


                    <Card>
                        <Stack spacing={1.5} p={2}>
                            <Grid container alignItems="center" spacing={1} mt={1}>
                                <Grid md={1}>
                                    <Typography variant="subtitle2">Sujet</Typography>
                                </Grid>
                                <Grid md={11}>
                                    <RHFTextField name="subject" sx={{ width: '100%' }} />
                                </Grid>
                            </Grid>
                            <Grid container spacing={1} mt={1}>
                                <AddMediaButton multiple variant="outlined" color="success" size="small" sx={{ mt: 1 }} />
                                <Button variant="outlined" color="success" sx={{ ml: 1, mt: 1 }} size="small" onClick={handleOpen}>Ajouter formulaire d'inscription</Button>
                                <Grid md={5} sx={{ ml: 1 }}>
                                    <RHFAutocomplete
                                        name="smartTags"
                                        label="Selectionner SMART TAGS"
                                        placeholder="+ Selectionner SMART TAGS"
                                        multiple
                                        size="small"
                                        freeSolo
                                        disableCloseOnSelect
                                        options={SmartTags_OPTIONS.map(tag => tag.label)}
                                        getOptionLabel={(option) => option}
                                        renderOption={(props, option) => (
                                            <li {...props} key={option}>
                                                {option}
                                            </li>
                                        )}
                                        renderTags={(selected, getTagProps) =>
                                            selected.map((option, index) => (
                                                <Chip
                                                    {...getTagProps({ index })}
                                                    key={option}
                                                    label={option}
                                                    size="small"
                                                    color="success"
                                                    variant="soft"
                                                />
                                            ))
                                        }
                                        style={{ width: "60%", marginBottom: 16 }}
                                    />
                                </Grid>
                            </Grid>

                            <RHFEditor simple name="description"
                                onChange={(value) => {
                                    console.log(value);
                                }}
                            />
                        </Stack>
                    </Card>
                </Stack>
            </Grid>
            <Modal
                open={open}
                onClose={handleClose}
                aria-labelledby="modal-modal-title"
                aria-describedby="modal-modal-description"
            >
                <Box sx={style} display="grid" gridTemplateRows="auto 1fr auto" borderRadius={2}>
                    <Box sx={{ p: 2 }}>
                        <Typography id="modal-modal-title" variant="h6" component="h2">
                            Inserer Formulaire
                        </Typography>
                    </Box>
                    <Divider sx={{ mb: 5 }} />

                    <FormLabel sx={{ color: "black" }}>Sélectionnez un formulaire ci-dessous à insérer</FormLabel>
                    <Box sx={{ p: 2 }}>
                        <RHFAutocomplete
                            name="registerFormType"
                            label="Sélectionnez un formulaire"
                            placeholder="+ Select a form below to insert"
                            freeSolo
                            options={RegisterFormType_OPTIONS.map(form => form.label)}
                            getOptionLabel={(option) => option}
                            renderOption={(props, option) => (
                                <li {...props} key={option}>
                                    {option}
                                </li>
                            )}
                            renderTags={(selected, getTagProps) =>
                                selected.map((option, index) => (
                                    <Chip
                                        {...getTagProps({ index })}
                                        key={option}
                                        label={option}
                                        size="small"
                                        color="success"
                                        variant="soft"
                                    />
                                ))
                            }
                            style={{ width: "100%", marginBottom: 16 }}
                        />
                    </Box>

                    <Divider />
                    <Box sx={{ display: 'flex', justifyContent: 'flex-end', p: 2 }}>
                        <Button onClick={handleClose} variant="outlined" color="inherit">Cancel</Button>
                        <Button variant="contained" color="inherit" sx={{ ml: 1 }}>Valider</Button>
                    </Box>
                </Box>
            </Modal>
        </>
    );

    const renderActions = (
        <>
            {mdUp && <Grid md={4} />}
            <Grid xs={12} md={8} sx={{ display: 'flex', justifyContent: 'end', py: 4 }}>
                <LoadingButton
                    type="submit"
                    variant="contained"
                    size="large"
                    loading={isSubmitting}
                    sx={{ ml: 2 }}
                >Enregistrer</LoadingButton>

            </Grid>
        </>
    );



    return (
        <FormProvider methods={methods} onSubmit={onSubmit}>
            <Grid container spacing={3}>
                {renderBasic}
                {renderActions}
            </Grid>
        </FormProvider>
    );
}
