import Chip from '@mui/material/Chip';
import TableRow from '@mui/material/TableRow';
import TableCell from '@mui/material/TableCell';
import {
  RHFAutocomplete,
} from '@/components/hook-form';
import { IMethodMondialRelayItem, MondialRelayMode } from '@/contexts/types/Shipping';


type Props = {
  row: IMethodMondialRelayItem;
};

export default function ConfigShippingMethodRow({
  row,
}: Props) {
  const { name, type, shippingArea, shippingMode } = row;
  const mondialRelayMode = Object.values(MondialRelayMode);


  return (
    <>
      <TableRow hover>
        <TableCell>{name}</TableCell>
        <TableCell>{type}</TableCell>
        <TableCell>{shippingArea.name}</TableCell>
        <TableCell>
          <RHFAutocomplete
            name="mondialRelayMode"
            disableClearable
            options={mondialRelayMode}
            value={shippingMode}
            getOptionLabel={(option) => option}
            renderOption={(props, option) => (
              <li {...props} key={option}>
                {option}
              </li>
            )}
            renderTags={(selected, getTagProps) =>
              selected.map((option, index) => (
                <Chip
                  {...getTagProps({ index })}
                  key={option}
                  label={option}
                  size="small"
                  color="info"
                  variant="soft"
                />
              ))
            }
          />
        </TableCell>
      </TableRow>
    </>
  );
}
