"use client"

import * as Yup from 'yup';
import { useForm } from 'react-hook-form';
import { yupResolver } from '@hookform/resolvers/yup';
import Chip from '@mui/material/Chip';
import Grid from '@mui/material/Unstable_Grid2';
import Card from '@mui/material/Card';
import Stack from '@mui/material/Stack';
import CardHeader from '@mui/material/CardHeader';
import { useResponsive } from '@/hooks/use-responsive';
import { useSnackbar } from '@/components/snackbar';
import FormProvider, {
    RHFTextField,
    RHFAutocomplete,
} from '@/components/hook-form';
import LoadingButton from '@mui/lab/LoadingButton';
import { countries } from '@/shared/assets/data/countries'
import { Box, Typography } from '@mui/material';


export default function ConfigVendeurView() {

    const mdUp = useResponsive('up', 'md');
    const { enqueueSnackbar } = useSnackbar();

    const NewShippingMethodSchema = Yup.object().shape({
        expediteur: Yup.string().required('Ce champ est requis'),
        rue: Yup.string().required('Ce champ est requis'),
        codePostal: Yup.string().required('Ce champ est requis'),
        ville: Yup.string().required('Ce champ est requis'),
        country: Yup.string().required('Ce champ est requis'),
        phone1: Yup.string().required('Ce champ est requis'),
        phone2: Yup.string(),
        mail: Yup.string().email('Veuillez saisir une adresse e-mail valide').required('Ce champ est requis'),
    });

    const methods = useForm({
        resolver: yupResolver(NewShippingMethodSchema),
    });

    const {
        reset,
        handleSubmit,
        formState: { isSubmitting },
    } = methods;

    const onSubmit = handleSubmit(async (data) => {
        try {
            await new Promise((resolve) => setTimeout(resolve, 500));
            reset();
            enqueueSnackbar('Config success!', { variant: 'success' });
            console.info('Form Data:', data);
        } catch (error) {
            console.error(error);
            enqueueSnackbar('Failed to configure vendeur.', { variant: 'error' });
        }
    });

    const renderDetails = (
        <>
            {mdUp && (
                <Grid xs={12} md={4}>
                    <Typography variant="h6" sx={{ mb: 0.5 }}>
                        Coordonnées du vendeur
                    </Typography>
                    <Typography variant="body2" sx={{ color: 'text.secondary' }}>
                        Configuration des coordonnées du vendeur.
                    </Typography>
                </Grid>
            )}

            <Grid xs={12} md={8}>
                <Card>
                    {!mdUp ? (<CardHeader title="Coordonnées du vendeur" />) : (<></>)}

                    <Stack spacing={3} sx={{ p: 3 }}>
                        <Box display="flex" flexDirection="column" alignItems="flex-start">
                            <Box display="flex" width="100%" marginBottom={2}>
                                <RHFTextField name="expediteur" label="Expéditeur" />
                                <RHFTextField name="mail" label="Adresse e-mail" type='email' sx={{ ml: 2 }} />
                            </Box>
                            <Box display="flex" width="100%" marginBottom={2} justifyContent="space-between">
                                <RHFTextField name="phone1" label="Téléphone" type='number' />
                                <RHFTextField name="phone2" label="Téléphone 2" type='number' sx={{ ml: 2 }} />
                            </Box>
                            <Box display="flex" width="100%" marginBottom={2} justifyContent="space-between">
                                <RHFTextField name="rue" label="Rue" />
                            </Box>
                            <Box display="flex" width="100%" marginBottom={2}>
                                <RHFTextField name="codePostal" label="Code Postal" sx={{ width: "30vh" }} />
                                <RHFTextField name="ville" label="Ville" sx={{ ml: 2, width: "50vh" }} />
                                <RHFAutocomplete
                                    name="country"
                                    label="Pays"
                                    placeholder="+ Pays"
                                    sx={{ width: "70vh", ml: 2 }}
                                    freeSolo
                                    disableCloseOnSelect
                                    options={countries.map(country => country.label)}
                                    getOptionLabel={(option) => option}
                                    renderOption={(props, option) => (
                                        <li {...props} key={option}>
                                            {option}
                                        </li>
                                    )}
                                    renderTags={(selected, getTagProps) =>
                                        selected.map((option, index) => (
                                            <Chip
                                                {...getTagProps({ index })}
                                                key={option}
                                                label={option}
                                                size="small"
                                                color="success"
                                                variant="soft"
                                            />
                                        ))
                                    }
                                />
                            </Box>
                        </Box>
                    </Stack>
                </Card>
            </Grid>
        </>
    );

    const renderActions = (
        <>
            {mdUp && <Grid md={4} />}
            <Grid xs={12} md={8} sx={{ display: 'flex', justifyContent: 'end', py: 4 }}>
                <LoadingButton
                    type="submit"
                    variant="contained"
                    size="large"
                    loading={isSubmitting}
                    sx={{ ml: 2 }}
                >Enregistrer</LoadingButton>

            </Grid>
        </>
    );


    return (
        <FormProvider methods={methods} onSubmit={onSubmit}>
            <Grid container spacing={3}>
                {renderDetails}
                {renderActions}
            </Grid>
        </FormProvider>
    );
}
