import { Modal, Typography } from "@mui/material";
import { m } from "framer-motion";
import CheckCircleOutlineIcon from '@mui/icons-material/CheckCircleOutline';

interface CustomModalProps {
  open: boolean;
  onClose: () => void;
  message: string;
}

export default function CustomModal({ open , onClose , message} : CustomModalProps) {
  return (
    <Modal
      className="flex items-center justify-center"
      open={open}
      onClose={onClose}
      aria-labelledby="modal-title"
      aria-describedby="modal-description"
    > 
      <div className="bg-white rounded-lg shadow p-6 flex flex-col justify-center items-center">
        <Typography variant="body2" id="modal-description" sx={{ mb: 2, fontSize: 20 }}>
          {message}
        </Typography>
        <m.div
          initial={{ scale: 0 }}
          animate={{ scale: 1 }}
          transition={{ duration: 0.5 }}
        >
          <CheckCircleOutlineIcon sx={{ color: "#00e676", fontSize: 100 }} />
        </m.div>
      </div>
    </Modal>
  );
}
