import Button from "@mui/material/Button";

import Tooltip from "@mui/material/Tooltip";
import MenuItem from "@mui/material/MenuItem";
import TableRow from "@mui/material/TableRow";
import Checkbox from "@mui/material/Checkbox";
import TableCell from "@mui/material/TableCell";
import IconButton from "@mui/material/IconButton";
import ListItemText from "@mui/material/ListItemText";

import { useBoolean } from "@/hooks/use-boolean";

import Iconify from "@/shared/components/iconify";
import { ConfirmDialog } from "@/shared/components/custom-dialog";
import CustomPopover, { usePopover } from "@/shared/components/custom-popover";

import { IUserItem } from "@/shared/types/user";
import ExpandLessIcon from '@mui/icons-material/ExpandLess';
import { useRouter } from "@/hooks";
import { paths } from "@/routes/paths";
import { useCallback, useState } from "react";
// ----------------------------------------------------------------------

type Props = {
  selected: boolean;
  onEditRow: VoidFunction;
  row: IUserItem;
  onSelectRow: VoidFunction;
  onDeleteRow: VoidFunction;
};

export default function UserTableRow({
  row,
  selected,
  onEditRow,
  onSelectRow,
  onDeleteRow,
}: Props) {
  const { name, company, role, email, phoneNumber, ref, state, city, address, zipCode, } = row;

  const [showDetails, setShowDetails] = useState(false);

  const confirm = useBoolean();
  const router = useRouter();

  const popover = usePopover();

  const handleClick = () => {
    setShowDetails(!showDetails);
  }

  const handleCheckBoxClick = (e: any) => {
    e.stopPropagation()
    onSelectRow()
  }

  return (
    <>
      <TableRow hover selected={selected} onClick={handleClick}>
        <TableCell padding="checkbox">
          <Checkbox checked={selected} onClick={handleCheckBoxClick} />
        </TableCell>

        <TableCell sx={{ display: "flex", alignItems: "center" }}>
          <ListItemText
            primary={name}
            secondary={email}
            primaryTypographyProps={{ variant: "body2" }}
            secondaryTypographyProps={{
              component: "span",
              color: "text.disabled",
            }}
          />
        </TableCell>

        <TableCell sx={{ whiteSpace: "nowrap" }}>{phoneNumber}</TableCell>

        <TableCell sx={{ whiteSpace: "nowrap" }}>{company}</TableCell>

        <TableCell sx={{ whiteSpace: "nowrap" }}>{role}</TableCell>
        <TableCell sx={{ whiteSpace: "nowrap" }}>{ref}</TableCell>

        <TableCell align="right" sx={{ px: 1, whiteSpace: "nowrap" }} onClick={(e: any) => e.stopPropagation()}>
          <IconButton
            color={popover.open ? "inherit" : "default"}
            onClick={popover.onOpen}
          >
            <Iconify icon="eva:more-vertical-fill" />
          </IconButton>
        </TableCell>
      </TableRow>
      {
        showDetails && (
          <TableRow>

            <TableCell padding="checkbox">
              <Tooltip title="Cacher les détails">
                <IconButton sx={{ color: "#64748b" }} onClick={handleClick} >
                  <ExpandLessIcon />
                </IconButton>
              </Tooltip>
            </TableCell>
            <TableCell sx={{ whiteSpace: "nowrap", color: "#637381", verticalAlign: 'top' }}>
              <p className="font-bold ">Région</p>
              <p className="text-black">{state}</p>
            </TableCell>

            <TableCell sx={{ whiteSpace: "nowrap", verticalAlign: 'top', color: "#637381" }}>
              <p className="font-bold">Ville</p>
              <p className="text-black">{city}</p>
            </TableCell>

            <TableCell colSpan={2} sx={{ whiteSpace: "normal", wordBreak: "break-word", color: "#637381", verticalAlign: 'top' }}>
              <p className="font-bold ">Adresse</p>
              <p className="text-black">{address}</p>
            </TableCell>

            <TableCell sx={{ whiteSpace: "nowrap", color: "#637381" , verticalAlign: 'top'}}>
              <p className="font-bold ">Code Postal</p>
              <p className="text-black">{zipCode}</p>
            </TableCell>

          </TableRow>
        )
      }

      <CustomPopover
        open={popover.open}
        onClose={popover.onClose}
        arrow="right-top"
        sx={{ width: 140 }}
      >
        <MenuItem
          onClick={() => {
            confirm.onTrue();
            popover.onClose();
          }}
          sx={{ color: "error.main" }}
        >
          <Iconify icon="solar:trash-bin-trash-bold" />
          Supprimer
        </MenuItem>

        <MenuItem
          onClick={() => {
            onEditRow();
            popover.onClose();
          }}
        >
          <Iconify icon="solar:pen-bold" />
          Modifier
        </MenuItem>
      </CustomPopover>

      <ConfirmDialog
        open={confirm.value}
        onClose={confirm.onFalse}
        title="Supprimer"
        content="Êtes-vous sûr de vouloir supprimer ?"
        action={
          <Button variant="contained" color="error" onClick={onDeleteRow}>
            Supprimer
          </Button>
        }
      />
    </>
  );
}
