export type ILive = {
  id: string;
  title: string;
  moderator: string;
  description: string;
  date: Date;
  time: Date;
  tags: string[];
  staging: boolean;
  chat: boolean;
  cache: boolean;
  externalVideo: boolean;
  image: string | null | File;
  videoFormat: string;
  products?: ILiveProduct[];
  comments?: ILiveComment[];
}

export enum LiveStatus {
  Ongoing = 'En cours',
  Upcoming = 'A venir',
  Replay = 'Replay'
}


export type ILiveItem = {
  id: string;
  title: string;
  moderator: string;
  description: string;
  startDate: Date;
  status: LiveStatus;
  tags: string[];
  staging: boolean;
  chat: boolean;
  cache: boolean;
  image: string;
  videoFormat: string;
};


export type ILiveComment = {
  id: string;
  body: string;
  live: string;
  createdAt: Date;
  senderId: string;
}

export type ILiveProduct = {
  id: string;
  name: string;
  sku: string;
  image: string;
  price: number;
}

export type ILiveStatistic = {
  timestamp: Date;
  viewerCount: number;
  messageCount: number;
  cartAdditionCount: number;
}

export type ILiveStatisticsSummary = {
  totalViewers: number;
  totalMessages: number;
  totalCartAdditions: number;
  statistics: ILiveStatistic[];
}

export type IMultipleLivesStatisticsSummary = {
  stats: {
    id: string;
    title: string;
    startDate: string;
    viewers: number;
    revenu: number;
    messages: number;
    cartAdditions: number;
    watchingHours: number;
  }[];
  total: {
    totalCartAdditions: number;
    totalMessages: number;
    totalRevenu: number;
    totalViewers: number;
    totalWatchingHours: number;
    avgWatchingHours: number;
  }
}


export type ILiveTableFilterValues = string | Date | string[] | null | undefined;



export type ILiveTableFilter = {
  startDate: Date | null;
  status: string | LiveStatus;
  tags: string[];
};



export type ILiveTableSort = {
  order: 'asc' | 'desc';
  orderBy: string;
};